@@ -21,7 +21,7 @@
 
 /*! \file channel.h
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.h 9266 2020-02-12 16:55:29Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_channel_h
@@ -30,7 +30,6 @@
 #include "ircd_defs.h"        /* KEYLEN, CHANNELLEN */
 #include "extban.h"
 
-#define IsMember(who, chan) ((find_channel_link(who, chan)) ? 1 : 0)
 #define AddMemberFlag(x, y) ((x)->flags |=  (y))
 #define DelMemberFlag(x, y) ((x)->flags &= ~(y))
 
@@ -133,22 +132,24 @@ extern bool channel_check_name(const char *, bool);
 extern int can_send(struct Channel *, struct Client *, struct ChannelMember *, const char *, bool);
 extern bool is_banned(struct Channel *, struct Client *);
 extern bool find_bmask(struct Client *, struct Channel*, const dlink_list *, struct Extban *);
-extern int has_member_flags(const struct ChannelMember *, const unsigned int);
+extern bool member_has_flags(const struct ChannelMember *, const unsigned int);
 
 extern void channel_do_join(struct Client *, char *, char *);
 extern void channel_do_part(struct Client *, char *, const char *);
 extern void remove_ban(struct Ban *, dlink_list *);
 extern void add_user_to_channel(struct Channel *, struct Client *, unsigned int, bool);
 extern void remove_user_from_channel(struct ChannelMember *);
-extern void channel_member_names(struct Client *, struct Channel *, bool);
+extern void channel_demote_members(struct Channel *, const struct Client *, unsigned int, const char);
+extern void channel_send_namereply(struct Client *, struct Channel *);
 extern void channel_send_modes(struct Client *, const struct Channel *);
-extern void channel_modes(const struct Channel *, const struct Client *, char *, char *);
+extern void channel_modes(const struct Channel *, const struct Client *, const struct ChannelMember *, char *, char *);
 extern void check_spambot_warning(struct Client *, const char *);
 extern void channel_free(struct Channel *);
 extern void channel_set_topic(struct Channel *, const char *, const char *, uintmax_t, bool);
 
-extern const char *get_member_status(const struct ChannelMember *, bool);
+extern const char *member_get_prefix(const struct ChannelMember *, bool);
+extern size_t member_get_prefix_len(const struct ChannelMember *, bool);
 
 extern struct Channel *channel_make(const char *);
-extern struct ChannelMember *find_channel_link(const struct Client *, const struct Channel *);
+extern struct ChannelMember *member_find_link(const struct Client *, const struct Channel *);
 #endif  /* INCLUDED_channel_h */
