@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.h
  * \brief Includes channel mode related definitions and structures.
- * \version $Id: channel_mode.h 9233 2020-01-31 17:31:08Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_channel_mode_h
@@ -86,7 +86,8 @@ enum
   MODE_NONOTICE     = 1 << 13,  /**< Clients cannot send NOTICE to the channel */
   MODE_HIDEBMASKS   = 1 << 14,  /**< Hides +b/+e/+I lists/changes for non-chanops everywhere */
   MODE_EXTLIMIT     = 1 << 15,  /**< Channel can make use of the extended ban list limit */
-  MODE_NONICKCHANGE = 1 << 16   /**< User is prevented from changing their nick while in this channel */
+  MODE_NONICKCHANGE = 1 << 16,  /**< User is prevented from changing their nick while in this channel */
+  MODE_NOKNOCK      = 1 << 17   /**< Clients may not use KNOCK on this channel */
 };
 
 #define HasCMode(x, y) ((x)->mode.mode &   (y))
