@@ -21,7 +21,7 @@
 
 /*! \file conf.h
  * \brief A header for the configuration functions.
- * \version $Id: conf.h 9368 2020-05-01 15:36:17Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_conf_h
@@ -177,7 +177,7 @@ struct config_general_entry
   unsigned int failed_oper_notice;
   unsigned int anti_spam_exit_message_time;
   unsigned int max_accept;
-  unsigned int max_watch;
+  unsigned int max_monitor;
   unsigned int whowas_history_length;
   unsigned int away_time;
   unsigned int away_count;
@@ -254,7 +254,7 @@ struct config_serverinfo_entry
   char *name;
   char *description;
   char *network_name;
-  char *network_desc;
+  char *network_description;
   char *rsa_private_key_file;
   char *tls_certificate_file;
   char *tls_dh_param_file;
