@@ -21,7 +21,7 @@
 
 /*! \file defaults.h
  * \brief The ircd defaults header for values and paths.
- * \version $Id: defaults.h 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_defaults_h
@@ -99,11 +99,9 @@
 
 /* ConfigServerInfo default values */
 #define NETWORK_NAME_DEFAULT "2600net"  /* default for network_name */
-#define NETWORK_DESC_DEFAULT "2600net IRC Network"  /* default for network_desc */
+#define NETWORK_DESCRIPTION_DEFAULT "2600net IRC Network"  /* default for network_description */
 
 /* General defaults */
-#define MAXIMUM_LINKS_DEFAULT 0         /* default for maximum_links */
-
 #define LINKS_DELAY_DEFAULT  300
 
 #define MAX_TARGETS_DEFAULT 4           /* default for max_targets */
