@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2015-2019 ircd-hybrid development team
+ *  Copyright (c) 2015-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls.h
  * \brief A header for generic TLS functions
- * \version $Id: tls.h 8957 2019-05-10 17:07:45Z michael $
+ * \version $Id$
  */
 
 #ifndef INCLUDED_tls_h
@@ -33,6 +33,8 @@
 #include "tls_openssl.h"
 #elif defined(HAVE_LIBGNUTLS)
 #include "tls_gnutls.h"
+#elif defined(HAVE_LIBWOLFSSL)
+#include "tls_wolfssl.h"
 #else
 #include "tls_none.h"
 #endif
@@ -55,7 +57,7 @@ typedef enum _tls_handshake_status
 
 extern bool tls_is_initialized(void);
 extern void tls_init(void);
-extern bool tls_new_cred(void);
+extern bool tls_new_credentials(void);
 
 extern const char *tls_get_cipher(const tls_data_t *);
 extern const char *tls_get_version(void);
@@ -72,6 +74,6 @@ extern void tls_shutdown(tls_data_t *);
 
 extern bool tls_set_ciphers(tls_data_t *, const char *);
 
-extern bool tls_verify_cert(tls_data_t *, tls_md_t, char **);
+extern bool tls_verify_certificate(tls_data_t *, tls_md_t, char **);
 
 #endif  /* INCLUDED_tls_h */
