@@ -21,7 +21,7 @@
 
 /*! \file m_join.c
  * \brief Includes required functions for processing the JOIN command.
- * \version $Id: m_join.c 9286 2020-02-22 22:48:39Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -40,10 +40,98 @@
 #include "modules.h"
 
 
-static void set_final_mode(const struct Mode *, const struct Mode *, char *, char *);
-static void remove_our_modes(struct Channel *, struct Client *);
-static void remove_a_mode(struct Channel *, struct Client *, int, const char);
+/* set_final_mode
+ *
+ * inputs       - channel mode
+ *              - old channel mode
+ * output       - NONE
+ * side effects - walk through all the channel modes turning off modes
+ *                that were on in oldmode but aren't on in mode.
+ *                Then walk through turning on modes that are on in mode
+ *                but were not set in oldmode.
+ */
+static void
+set_final_mode(const struct Mode *mode, const struct Mode *oldmode, char *mbuf, char *pbuf)
+{
+  int what = MODE_QUERY;
 
+  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
+  {
+    if (tab->mode && (tab->mode & mode->mode) && !(tab->mode & oldmode->mode))
+    {
+      if (what != MODE_ADD)
+      {
+        *mbuf++ = '+';
+        what = MODE_ADD;
+      }
+
+      *mbuf++ = tab->letter;
+    }
+  }
+
+  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
+  {
+    if (tab->mode && (tab->mode & oldmode->mode) && !(tab->mode & mode->mode))
+    {
+      if (what != MODE_DEL)
+      {
+        *mbuf++ = '-';
+        what = MODE_DEL;
+      }
+
+      *mbuf++ = tab->letter;
+    }
+  }
+
+  if (oldmode->limit && mode->limit == 0)
+  {
+    if (what != MODE_DEL)
+    {
+      *mbuf++ = '-';
+      what = MODE_DEL;
+    }
+
+    *mbuf++ = 'l';
+  }
+
+  if (oldmode->key[0] && mode->key[0] == '\0')
+  {
+    if (what != MODE_DEL)
+    {
+      *mbuf++ = '-';
+      what = MODE_DEL;
+    }
+
+    *mbuf++ = 'k';
+    pbuf += sprintf(pbuf, "%s ", oldmode->key);
+  }
+
+  if (mode->limit && oldmode->limit != mode->limit)
+  {
+    if (what != MODE_ADD)
+    {
+      *mbuf++ = '+';
+      what = MODE_ADD;
+    }
+
+    *mbuf++ = 'l';
+    pbuf += sprintf(pbuf, "%u ", mode->limit);
+  }
+
+  if (mode->key[0] && strcmp(oldmode->key, mode->key))
+  {
+    if (what != MODE_ADD)
+    {
+      *mbuf++ = '+';
+      what = MODE_ADD;
+    }
+
+    *mbuf++ = 'k';
+    pbuf += sprintf(pbuf, "%s ", mode->key);
+  }
+
+  *mbuf = '\0';
+}
 
 /*! \brief JOIN command handler
  *
@@ -60,10 +148,7 @@ static void remove_a_mode(struct Channel *, struct Client *, int, const char);
 static void
 m_join(struct Client *source_p, int parc, char *parv[])
 {
-  if (EmptyString(parv[1]))
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "JOIN");
-  else
-    channel_do_join(source_p, parv[1], parv[2]);
+  channel_do_join(source_p, parv[1], parv[2]);
 }
 
 /* ms_join()
@@ -82,23 +167,16 @@ m_join(struct Client *source_p, int parc, char *parv[])
 static void
 ms_join(struct Client *source_p, int parc, char *parv[])
 {
-  uintmax_t newts = 0;
-  uintmax_t oldts = 0;
   bool keep_our_modes = true;
   bool keep_new_modes = true;
   bool isnew = false;
-  const char *servername = NULL;
-  struct Channel *channel = NULL;
-  struct Mode mode, *oldmode;
+  struct Mode mode = { .mode = 0, .limit = 0, .key[0] = '\0' };
   char modebuf[MODEBUFLEN];
   char parabuf[MODEBUFLEN];
 
   if (!IsClient(source_p))
     return;
 
-  if (parc < 4)
-    return;
-
   if (channel_check_name(parv[2], false) == false)
   {
     sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
@@ -107,18 +185,15 @@ ms_join(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  mode.mode = mode.limit = 0;
-  mode.key[0] = '\0';
-
-  if ((channel = hash_find_channel(parv[2])) == NULL)
+  struct Channel *channel = hash_find_channel(parv[2]);
+  if (channel == NULL)
   {
     isnew = true;
     channel = channel_make(parv[2]);
   }
 
-  newts   = strtoumax(parv[1], NULL, 10);
-  oldts   = channel->creation_time;
-  oldmode = &channel->mode;
+  uintmax_t newts = strtoumax(parv[1], NULL, 10);
+  uintmax_t oldts = channel->creation_time;
 
   if (newts == 0 && isnew == false && oldts)
   {
@@ -144,6 +219,8 @@ ms_join(struct Client *source_p, int parc, char *parv[])
   else
     keep_new_modes = false;
 
+  struct Mode *oldmode = &channel->mode;
+
   if (keep_new_modes == false)
     mode = *oldmode;
   else if (keep_our_modes == true)
@@ -159,18 +236,22 @@ ms_join(struct Client *source_p, int parc, char *parv[])
   set_final_mode(&mode, oldmode, modebuf, parabuf);
   channel->mode = mode;
 
+  const struct Client *origin = source_p->servptr;
+  if (IsHidden(source_p->servptr) || ConfigServerHide.hide_servers)
+    origin = &me;
+
   /* Lost the TS, other side wins, so remove modes on this side */
   if (keep_our_modes == false)
   {
-    remove_our_modes(channel, source_p->servptr);
+    channel_demote_members(channel, origin, CHFL_CHANOP, 'o');
+    channel_demote_members(channel, origin, CHFL_HALFOP, 'h');
+    channel_demote_members(channel, origin, CHFL_VOICE, 'v');
 
     if (channel->topic[0])
     {
       channel_set_topic(channel, "", "", 0, false);
       sendto_channel_local(NULL, channel, 0, 0, 0, ":%s TOPIC %s :",
-                           (IsHidden(source_p->servptr) ||
-                           ConfigServerHide.hide_servers) ?
-                           me.name : source_p->servptr->name, channel->name);
+                           origin->name, channel->name);
     }
 
     sendto_channel_local(NULL, channel, 0, 0, 0,
@@ -179,17 +260,10 @@ ms_join(struct Client *source_p, int parc, char *parv[])
   }
 
   if (*modebuf)
-  {
-    servername = (ConfigServerHide.hide_servers || IsHidden(source_p->servptr)) ?
-                  me.name : source_p->servptr->name;
-
-    /* This _SHOULD_ be to ALL_MEMBERS
-     * It contains only +imnpstlk, etc */
     sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s %s",
-                         servername, channel->name, modebuf, parabuf);
-  }
+                         origin->name, channel->name, modebuf, parabuf);
 
-  if (!IsMember(source_p, channel))
+  if (member_find_link(source_p, channel) == NULL)
   {
     add_user_to_channel(channel, source_p, 0, true);
 
@@ -211,208 +285,14 @@ ms_join(struct Client *source_p, int parc, char *parv[])
                 source_p->id, channel->creation_time, channel->name);
 }
 
-/* set_final_mode
- *
- * inputs       - channel mode
- *              - old channel mode
- * output       - NONE
- * side effects - walk through all the channel modes turning off modes
- *                that were on in oldmode but aren't on in mode.
- *                Then walk through turning on modes that are on in mode
- *                but were not set in oldmode.
- */
-static void
-set_final_mode(const struct Mode *mode, const struct Mode *oldmode, char *mbuf, char *pbuf)
-{
-  int what = 0, len = 0;
-
-  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
-  {
-    if (tab->mode && (tab->mode & mode->mode) && !(tab->mode & oldmode->mode))
-    {
-      if (what != 1)
-      {
-        *mbuf++ = '+';
-        what = 1;
-      }
-
-      *mbuf++ = tab->letter;
-    }
-  }
-
-  for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
-  {
-    if (tab->mode && (tab->mode & oldmode->mode) && !(tab->mode & mode->mode))
-    {
-      if (what != -1)
-      {
-        *mbuf++ = '-';
-        what = -1;
-      }
-
-      *mbuf++ = tab->letter;
-    }
-  }
-
-  if (oldmode->limit && mode->limit == 0)
-  {
-    if (what != -1)
-    {
-      *mbuf++ = '-';
-      what = -1;
-    }
-
-    *mbuf++ = 'l';
-  }
-
-  if (oldmode->key[0] && mode->key[0] == '\0')
-  {
-    if (what != -1)
-    {
-      *mbuf++ = '-';
-      what = -1;
-    }
-
-    *mbuf++ = 'k';
-    len = sprintf(pbuf, "%s ", oldmode->key);
-    pbuf += len;
-  }
-
-  if (mode->limit && oldmode->limit != mode->limit)
-  {
-    if (what != 1)
-    {
-      *mbuf++ = '+';
-      what = 1;
-    }
-
-    *mbuf++ = 'l';
-    len = sprintf(pbuf, "%u ", mode->limit);
-    pbuf += len;
-  }
-
-  if (mode->key[0] && strcmp(oldmode->key, mode->key))
-  {
-    if (what != 1)
-    {
-      *mbuf++ = '+';
-      what = 1;
-    }
-
-    *mbuf++ = 'k';
-    len = sprintf(pbuf, "%s ", mode->key);
-    pbuf += len;
-  }
-
-  *mbuf = '\0';
-}
-
-/* remove_our_modes()
- *
- * inputs       - pointer to channel to remove modes from
- *              - client pointer
- * output       - NONE
- * side effects - Go through the local members, remove all their
- *                chanop modes etc., this side lost the TS.
- */
-static void
-remove_our_modes(struct Channel *channel, struct Client *source_p)
-{
-  remove_a_mode(channel, source_p, CHFL_CHANOP, 'o');
-  remove_a_mode(channel, source_p, CHFL_HALFOP, 'h');
-  remove_a_mode(channel, source_p, CHFL_VOICE, 'v');
-}
-
-/* remove_a_mode()
- *
- * inputs       -
- * output       - NONE
- * side effects - remove ONE mode from a channel
- */
-static void
-remove_a_mode(struct Channel *channel, struct Client *source_p, int mask, const char flag)
-{
-  dlink_node *node = NULL;
-  char lmodebuf[MODEBUFLEN];
-  char sendbuf[MODEBUFLEN];
-  const char *lpara[MAXMODEPARAMS];
-  int count = 0, lcount = 0;
-  char *mbuf = lmodebuf;
-
-  *mbuf++ = '-';
-
-  for (lcount = 0; lcount < MAXMODEPARAMS; ++lcount)
-    lpara[lcount] = "";
-
-  sendbuf[0] = '\0';
-
-  DLINK_FOREACH(node, channel->members.head)
-  {
-    struct ChannelMember *member = node->data;
-
-    if ((member->flags & mask) == 0)
-      continue;
-
-    member->flags &= ~mask;
-
-    lpara[count++] = member->client->name;
-
-    *mbuf++ = flag;
-
-    if (count >= MAXMODEPARAMS)
-    {
-      for (lcount = 0; lcount < MAXMODEPARAMS; ++lcount)
-      {
-        if (*lpara[lcount] == '\0')
-          break;
-
-        strlcat(sendbuf, " ", sizeof(sendbuf));
-        strlcat(sendbuf, lpara[lcount], sizeof(sendbuf));
-        lpara[lcount] = "";
-      }
-
-      *mbuf = '\0';
-      sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                           (IsHidden(source_p) ||
-                           ConfigServerHide.hide_servers) ?
-                           me.name : source_p->name,
-                           channel->name, lmodebuf, sendbuf);
-      mbuf = lmodebuf;
-      *mbuf++ = '-';
-      count = 0;
-      sendbuf[0] = '\0';
-    }
-  }
-
-  if (count)
-  {
-    *mbuf = '\0';
-
-    for (lcount = 0; lcount < MAXMODEPARAMS; ++lcount)
-    {
-      if (*lpara[lcount] == '\0')
-        break;
-
-      strlcat(sendbuf, " ", sizeof(sendbuf));
-      strlcat(sendbuf, lpara[lcount], sizeof(sendbuf));
-    }
-
-    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
-                         (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
-                         me.name : source_p->name, channel->name, lmodebuf, sendbuf);
-  }
-}
-
 static struct Message join_msgtab =
 {
   .cmd = "JOIN",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_join,
-  .handlers[SERVER_HANDLER] = ms_join,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_join
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_join, .args_min = 2 },
+  .handlers[SERVER_HANDLER] = { .handler = ms_join, .args_min = 4 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_join, .args_min = 2 }
 };
 
 static void
@@ -429,7 +309,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9286 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
