@@ -21,7 +21,7 @@
 
 /*! \file m_kick.c
  * \brief Includes required functions for processing the KICK command.
- * \version $Id: m_kick.c 9364 2020-04-30 19:24:10Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -57,14 +57,6 @@
 static void
 m_kick(struct Client *source_p, int parc, char *parv[])
 {
-  char reason[KICKLEN + 1];
-
-  if (EmptyString(parv[2]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "KICK");
-    return;
-  }
-
   struct Channel *channel = hash_find_channel(parv[1]);
   if (channel == NULL)
   {
@@ -72,14 +64,14 @@ m_kick(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  struct ChannelMember *member_source = find_channel_link(source_p, channel);
+  struct ChannelMember *member_source = member_find_link(source_p, channel);
   if (member_source == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, channel->name);
     return;
   }
 
-  if (!has_member_flags(member_source, CHFL_CHANOP | CHFL_HALFOP))
+  if (member_has_flags(member_source, CHFL_CHANOP | CHFL_HALFOP) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, channel->name);
     return;
@@ -89,22 +81,23 @@ m_kick(struct Client *source_p, int parc, char *parv[])
   if (target_p == NULL)
     return;  /* find_chasing sends ERR_NOSUCHNICK */
 
-  struct ChannelMember *member_target = find_channel_link(target_p, channel);
+  struct ChannelMember *member_target = member_find_link(target_p, channel);
   if (member_target == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, channel->name);
     return;
   }
 
-  if (has_member_flags(member_source, CHFL_HALFOP) && !has_member_flags(member_source, CHFL_CHANOP))
+  if (member_has_flags(member_source, CHFL_CHANOP) == false)
   {
-    if (has_member_flags(member_target, CHFL_CHANOP | CHFL_HALFOP))
+    if (member_has_flags(member_target, CHFL_CHANOP | CHFL_HALFOP) == true)
     {
       sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, channel->name);
       return;
     }
   }
 
+  char reason[KICKLEN + 1];
   if (!EmptyString(parv[3]))
     strlcpy(reason, parv[3], sizeof(reason));
   else
@@ -136,11 +129,6 @@ m_kick(struct Client *source_p, int parc, char *parv[])
 static void
 ms_kick(struct Client *source_p, int parc, char *parv[])
 {
-  char reason[KICKLEN + 1];
-
-  if (EmptyString(parv[2]))
-    return;
-
   struct Channel *channel = hash_find_channel(parv[1]);
   if (channel == NULL)
     return;
@@ -149,10 +137,11 @@ ms_kick(struct Client *source_p, int parc, char *parv[])
   if (target_p == NULL)
     return;
 
-  struct ChannelMember *member_target = find_channel_link(target_p, channel);
+  struct ChannelMember *member_target = member_find_link(target_p, channel);
   if (member_target == NULL)
     return;
 
+  char reason[KICKLEN + 1];
   if (!EmptyString(parv[3]))
     strlcpy(reason, parv[3], sizeof(reason));
   else
@@ -177,14 +166,11 @@ ms_kick(struct Client *source_p, int parc, char *parv[])
 static struct Message kick_msgtab =
 {
   .cmd = "KICK",
-  .args_min = 3,
-  .args_max = MAXPARA,
-  .flags = MFLG_ENDGRACE,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_kick,
-  .handlers[SERVER_HANDLER] = ms_kick,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_kick
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_kick, .args_min = 3, .end_grace_period = true },
+  .handlers[SERVER_HANDLER] = { .handler = ms_kick, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_kick, .args_min = 3, .end_grace_period = true }
 };
 
 static void
@@ -201,7 +187,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9364 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
