@@ -21,7 +21,7 @@
 
 /*! \file m_kill.c
  * \brief Includes required functions for processing the KILL command.
- * \version $Id: m_kill.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -55,19 +55,13 @@
 static void
 mo_kill(struct Client *source_p, int parc, char *parv[])
 {
-  char buf[IRCD_BUFSIZE] = "";
+  char buf[IRCD_BUFSIZE];
   char def_reason[] = CONF_NOREASON;
 
-  if (EmptyString(parv[1]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "KILL");
-    return;
-  }
-
   char *reason = parv[2];  /* Either defined or NULL (parc >= 2!!) */
   if (!EmptyString(reason))
   {
-    if (strlen(reason) > (size_t)REASONLEN)
+    if (strlen(reason) > REASONLEN)
       reason[REASONLEN] = '\0';
   }
   else
@@ -165,15 +159,9 @@ mo_kill(struct Client *source_p, int parc, char *parv[])
 static void
 ms_kill(struct Client *source_p, int parc, char *parv[])
 {
-  char buf[IRCD_BUFSIZE] = "";
+  char buf[IRCD_BUFSIZE];
   char def_reason[] = CONF_NOREASON;
 
-  if (parc < 3 || EmptyString(parv[2]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "KILL");
-    return;
-  }
-
   struct Client *target_p = find_person(source_p, parv[1]);
   if (target_p == NULL)
     return;
@@ -251,13 +239,11 @@ ms_kill(struct Client *source_p, int parc, char *parv[])
 static struct Message kill_msgtab =
 {
   .cmd = "KILL",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_kill,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_kill
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_kill, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_kill, .args_min = 2 }
 };
 
 static void
@@ -274,7 +260,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
