@@ -21,7 +21,7 @@
 
 /*! \file m_message.c
  * \brief Includes required functions for processing the PRIVMSG/NOTICE command.
- * \version $Id: m_message.c 9364 2020-04-30 19:24:10Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -121,7 +121,7 @@ flood_attack_client(bool notice, struct Client *source_p, struct Client *target_
   {
     if (!HasFlag(target_p, FLAGS_FLOOD_NOTICED))
     {
-      sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE, "Possible Flooder %s on %s target: %s",
+      sendto_realops_flags(UMODE_FLOOD, L_ALL, SEND_NOTICE, "Possible Flooder %s on %s target: %s",
                            client_get_name(source_p, HIDE_IP),
                            source_p->servptr->name, target_p->name);
       AddFlag(target_p, FLAGS_FLOOD_NOTICED);
@@ -172,7 +172,7 @@ flood_attack_channel(bool notice, struct Client *source_p, struct Channel *chann
   {
     if (!IsSetFloodNoticed(channel))
     {
-      sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE, "Possible Flooder %s on %s target: %s",
+      sendto_realops_flags(UMODE_FLOOD, L_ALL, SEND_NOTICE, "Possible Flooder %s on %s target: %s",
                            client_get_name(source_p, HIDE_IP),
                            source_p->servptr->name, channel->name);
       SetFloodNoticed(channel);
@@ -312,8 +312,7 @@ msg_client(bool notice, struct Client *source_p, struct Client *target_p,
  *		- nick stuff to grok for opers
  *		- text to send if grok
  * output	- none
- * side effects	- old style username@server is handled here for non opers
- *		  opers are allowed username%hostname@server
+ * side effects	- old style nick@server is handled here for non opers
  *		  all the traditional oper type messages are also parsed here.
  *		  i.e. "/msg #some.host."
  *		  However, syntax has been changed.
@@ -321,17 +320,13 @@ msg_client(bool notice, struct Client *source_p, struct Client *target_p,
  *		  now becomes     "/msg $#some.host.mask"
  *		  previous syntax of: "/msg $some.server.mask" remains
  *		  This disambiguates the syntax.
- *
- * XXX		  N.B. dalnet changed it to nick@server as have other servers.
- *		  we will stick with tradition for now.
- *		- Dianora
  */
 static void
 handle_special(bool notice, struct Client *source_p,
                const char *nick, const char *text)
 {
   /*
-   * user[%host]@server addressed?
+   * nick@server addressed?
    */
   const char *server = strchr(nick, '@');
   if (server)
@@ -343,12 +338,6 @@ handle_special(bool notice, struct Client *source_p,
       return;
     }
 
-    if (!HasUMode(source_p, UMODE_OPER) && strchr(nick, '%'))
-    {
-      sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, nick);
-      return;
-    }
-
     if (!IsMe(target_p))
     {
       sendto_one(target_p, ":%s %s %s :%s", source_p->id, command[notice], nick, text);
@@ -506,15 +495,15 @@ build_target_list(bool notice, struct Client *source_p, char *list, const char *
       }
 
       /*
-       * At this point, name+1 should be a channel name i.e. #foo. If the channel
+       * At this point, name should be a channel name i.e. #foo. If the channel
        * is found, fine, if not report an error.
        */
       if ((target = hash_find_channel(name)))
       {
         if (IsClient(source_p) && !HasFlag(source_p, FLAGS_SERVICE))
         {
-          if (!has_member_flags(find_channel_link(source_p, target),
-                                CHFL_CHANOP|CHFL_HALFOP|CHFL_VOICE))
+          if (member_has_flags(member_find_link(source_p, target),
+                               CHFL_CHANOP|CHFL_HALFOP|CHFL_VOICE) == false)
           {
             sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, with_prefix);
             continue;
@@ -559,14 +548,14 @@ build_target_list(bool notice, struct Client *source_p, char *list, const char *
 static void
 m_message(bool notice, struct Client *source_p, int parc, char *parv[])
 {
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     if (notice == false)
       sendto_one_numeric(source_p, &me, ERR_NORECIPIENT, command[notice]);
     return;
   }
 
-  if (parc < 3 || EmptyString(parv[2]))
+  if (EmptyString(parv[2]))
   {
     if (notice == false)
       sendto_one_numeric(source_p, &me, ERR_NOTEXTTOSEND);
@@ -615,24 +604,21 @@ m_notice(struct Client *source_p, int parc, char *parv[])
 static struct Message privmsg_msgtab =
 {
   .cmd = "PRIVMSG",
-  .args_max = MAXPARA,
-  .flags = MFLG_ENDGRACE,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_privmsg,
-  .handlers[SERVER_HANDLER] = m_privmsg,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_privmsg
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_privmsg, .end_grace_period = true },
+  .handlers[SERVER_HANDLER] = { .handler = m_privmsg },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_privmsg, .end_grace_period = true }
 };
 
 static struct Message notice_msgtab =
 {
   .cmd = "NOTICE",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_notice,
-  .handlers[SERVER_HANDLER] = m_notice,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_notice
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_notice },
+  .handlers[SERVER_HANDLER] = { .handler = m_notice },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_notice }
 };
 
 static void
@@ -651,7 +637,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9364 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
