@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 9304 2020-02-25 10:51:22Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -41,7 +41,7 @@
 #include "parse.h"
 #include "modules.h"
 #include "packet.h"
-#include "watch.h"
+#include "monitor.h"
 #include "misc.h"
 #include "id.h"
 #include "ipcache.h"
@@ -224,7 +224,7 @@ change_local_nick(struct Client *source_p, const char *nick)
   {
     source_p->tsinfo = event_base->time.sec_real;
     clear_ban_cache_list(&source_p->channel);
-    watch_check_hash(source_p, RPL_LOGOFF);
+    monitor_signoff(source_p);
 
     if (HasUMode(source_p, UMODE_REGISTERED))
     {
@@ -257,7 +257,7 @@ change_local_nick(struct Client *source_p, const char *nick)
   hash_add_client(source_p);
 
   if (samenick == false)
-    watch_check_hash(source_p, RPL_LOGON);
+    monitor_signon(source_p);
 
   /* fd_desc is long enough */
   fd_note(source_p->connection->fd, "Nick: %s", source_p->name);
@@ -287,7 +287,7 @@ change_remote_nick(struct Client *source_p, char *parv[])
   if (samenick == false)
   {
     DelUMode(source_p, UMODE_REGISTERED);
-    watch_check_hash(source_p, RPL_LOGOFF);
+    monitor_signoff(source_p);
 
     source_p->tsinfo = strtoumax(parv[2], NULL, 10);
     assert(source_p->tsinfo);
@@ -310,7 +310,7 @@ change_remote_nick(struct Client *source_p, char *parv[])
   hash_add_client(source_p);
 
   if (samenick == false)
-    watch_check_hash(source_p, RPL_LOGON);
+    monitor_signon(source_p);
 }
 
 /*!
@@ -322,40 +322,37 @@ change_remote_nick(struct Client *source_p, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *
- *      - parv[ 0] = command
  *      - parv[ 1] = nickname
  *      - parv[ 2] = hop count
  *      - parv[ 3] = TS
  *      - parv[ 4] = umode
  *      - parv[ 5] = username
  *      - parv[ 6] = hostname
- *      - parv[ 7] = ip
- *      - parv[ 8] = uid
- *      - parv[ 9] = services account
- *      - parv[10] = ircname (gecos)
+ *      - parv[ 7] = real host
+ *      - parv[ 8] = IP address
+ *      - parv[ 9] = uid
+ *      - parv[10] = services id (account name)
+ *      - parv[11] = ircname (gecos)
  */
 static void
 uid_from_server(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *client_p = NULL;
-
-  client_p = client_make(source_p->from);
+  struct Client *client_p = client_make(source_p->from);
   client_p->servptr = source_p;
   client_p->hopcount = atoi(parv[2]);
   client_p->tsinfo = strtoumax(parv[3], NULL, 10);
 
-  strlcpy(client_p->name, parv[1], sizeof(client_p->name));
-  strlcpy(client_p->info, parv[parc - 1], sizeof(client_p->info));
-  strlcpy(client_p->host, parv[6], sizeof(client_p->host));
-  strlcpy(client_p->username, parv[5], sizeof(client_p->username));
-
   /* TBR: compatibility mode */
   const int does_rhost = parc == 12;
 
+  strlcpy(client_p->name, parv[1], sizeof(client_p->name));
+  strlcpy(client_p->username, parv[5], sizeof(client_p->username));
+  strlcpy(client_p->host, parv[6], sizeof(client_p->host));
   strlcpy(client_p->realhost, parv[6 + does_rhost], sizeof(client_p->realhost));
   strlcpy(client_p->sockhost, parv[7 + does_rhost], sizeof(client_p->sockhost));
   strlcpy(client_p->id, parv[8 + does_rhost], sizeof(client_p->id));
   strlcpy(client_p->account, parv[9 + does_rhost], sizeof(client_p->account));
+  strlcpy(client_p->info, parv[parc - 1], sizeof(client_p->info));
 
   struct addrinfo hints, *res;
   memset(&hints, 0, sizeof(hints));
@@ -382,12 +379,12 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   for (const char *m = &parv[4][1]; *m; ++m)
   {
     const struct user_modes *tab = umode_map[(unsigned char)*m];
-
     if (tab == NULL)
       continue;
+
     if ((tab->flag & UMODE_INVISIBLE) && !HasUMode(client_p, UMODE_INVISIBLE))
       ++Count.invisi;
-    if ((tab->flag & UMODE_OPER) && !HasUMode(client_p, UMODE_OPER))
+    else if ((tab->flag & UMODE_OPER) && !HasUMode(client_p, UMODE_OPER))
       ++Count.oper;
 
     AddUMode(client_p, tab->flag);
@@ -412,18 +409,6 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
  *      - parv[ 4] = umode
  *      - parv[ 5] = username
  *      - parv[ 6] = hostname
- *      - parv[ 7] = ip
- *      - parv[ 8] = uid
- *      - parv[ 9] = services id (account name)
- *      - parv[10] = ircname (gecos)
- *  or with CAPAB_RHOST (parc == 12):
- *      - parv[ 0] = command
- *      - parv[ 1] = nickname
- *      - parv[ 2] = hop count
- *      - parv[ 3] = TS
- *      - parv[ 4] = umode
- *      - parv[ 5] = username
- *      - parv[ 6] = hostname
  *      - parv[ 7] = real host
  *      - parv[ 8] = IP address
  *      - parv[ 9] = uid
@@ -617,15 +602,14 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
 static void
 mr_nick(struct Client *source_p, int parc, char *parv[])
 {
-  char nick[NICKLEN + 1] = "";
-
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
     return;
   }
 
   /* Copy the nick and terminate it */
+  char nick[NICKLEN + 1];
   strlcpy(nick, parv[1], IRCD_MIN(sizeof(nick), ConfigServerInfo.max_nick_length + 1));
 
   /* Check the nickname is ok */
@@ -667,18 +651,18 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
 static void
 m_nick(struct Client *source_p, int parc, char *parv[])
 {
-  char nick[NICKLEN + 1] = "";
   const struct ResvItem *resv = NULL;
 
   assert(MyClient(source_p));
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
     return;
   }
 
   /* Terminate nick to NICKLEN */
+  char nick[NICKLEN + 1];
   strlcpy(nick, parv[1], IRCD_MIN(sizeof(nick), ConfigServerInfo.max_nick_length + 1));
 
   /* Check the nickname is ok */
@@ -704,7 +688,7 @@ m_nick(struct Client *source_p, int parc, char *parv[])
   {
     struct ChannelMember *member = node->data;
 
-    if ((member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE)) == 0)
+    if (member_has_flags(member, CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE) == false)
     {
       if (HasCMode(member->channel, MODE_NONICKCHANGE))
       {
@@ -764,9 +748,6 @@ m_nick(struct Client *source_p, int parc, char *parv[])
 static void
 ms_nick(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc != 3 || EmptyString(parv[parc - 1]))
-    return;
-
   if (!IsClient(source_p))
     return;  /* Servers and unknown clients can't change nicks.. */
 
@@ -808,18 +789,6 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
  *      - parv[ 4] = umode
  *      - parv[ 5] = username
  *      - parv[ 6] = hostname
- *      - parv[ 7] = ip
- *      - parv[ 8] = uid
- *      - parv[ 9] = services id (account name)
- *      - parv[10] = ircname (gecos)
- *  or with CAPAB_RHOST (parc == 12):
- *      - parv[ 0] = command
- *      - parv[ 1] = nickname
- *      - parv[ 2] = hop count
- *      - parv[ 3] = TS
- *      - parv[ 4] = umode
- *      - parv[ 5] = username
- *      - parv[ 6] = hostname
  *      - parv[ 7] = real host
  *      - parv[ 8] = IP address
  *      - parv[ 9] = uid
@@ -829,7 +798,7 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
 static void
 ms_uid(struct Client *source_p, int parc, char *parv[])
 {
-  /* TBR: compatibility mode */
+/* TBR: compatibility mode */
   const int does_rhost = parc == 12;
 
   if (check_clean_nick(source_p, parv[1]) == false ||
@@ -879,25 +848,21 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
 static struct Message nick_msgtab =
 {
   .cmd = "NICK",
-  .args_max = MAXPARA,
-  .flags = MFLG_ENDGRACE,
-  .handlers[UNREGISTERED_HANDLER] = mr_nick,
-  .handlers[CLIENT_HANDLER] = m_nick,
-  .handlers[SERVER_HANDLER] = ms_nick,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_nick
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_nick },
+  .handlers[CLIENT_HANDLER] = { .handler = m_nick, .end_grace_period = true },
+  .handlers[SERVER_HANDLER] = { .handler = ms_nick, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_nick }
 };
 
 static struct Message uid_msgtab =
 {
   .cmd = "UID",
-  .args_min = 11,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_uid,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_ignore },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_uid, .args_min = 11 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -916,7 +881,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9304 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
