@@ -21,7 +21,7 @@
 
 /*! \file m_quit.c
  * \brief Includes required functions for processing the QUIT command.
- * \version $Id: m_quit.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -72,7 +72,7 @@ m_quit(struct Client *source_p, int parc, char *parv[])
 static void
 ms_quit(struct Client *source_p, int parc, char *parv[])
 {
-  char reason[KICKLEN + 1] = "";
+  char reason[KICKLEN + 1] = "";  /* Essential that buf[0] = '\0' */
 
   if (!EmptyString(parv[1]))
     strlcpy(reason, parv[1], sizeof(reason));
@@ -83,12 +83,11 @@ ms_quit(struct Client *source_p, int parc, char *parv[])
 static struct Message quit_msgtab =
 {
   .cmd = "QUIT",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_quit,
-  .handlers[CLIENT_HANDLER] = m_quit,
-  .handlers[SERVER_HANDLER] = ms_quit,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_quit
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_quit },
+  .handlers[CLIENT_HANDLER] = { .handler = m_quit },
+  .handlers[SERVER_HANDLER] = { .handler = ms_quit },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_quit }
 };
 
 static void
@@ -105,7 +104,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
