@@ -21,7 +21,7 @@
 
 /*! \file m_admin.c
  * \brief Includes required functions for processing the ADMIN command.
- * \version $Id: m_admin.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -83,7 +83,7 @@ m_admin(struct Client *source_p, int parc, char *parv[])
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s ADMIN :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s ADMIN :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
   do_admin(source_p);
@@ -103,7 +103,7 @@ m_admin(struct Client *source_p, int parc, char *parv[])
 static void
 ms_admin(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s ADMIN :%s", 1, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s ADMIN :%s", 1, parv)->ret != HUNTED_ISME)
     return;
 
   do_admin(source_p);
@@ -112,12 +112,11 @@ ms_admin(struct Client *source_p, int parc, char *parv[])
 static struct Message admin_msgtab =
 {
   .cmd = "ADMIN",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_admin,
-  .handlers[SERVER_HANDLER] = ms_admin,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_admin
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_admin },
+  .handlers[SERVER_HANDLER] = { .handler = ms_admin },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_admin }
 };
 
 static void
@@ -134,7 +133,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
