@@ -21,7 +21,7 @@
 
 /*! \file m_away.c
  * \brief Includes required functions for processing the AWAY command.
- * \version $Id: m_away.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -115,12 +115,11 @@ m_away(struct Client *source_p, int parc, char *parv[])
 static struct Message away_msgtab =
 {
   .cmd = "AWAY",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_away,
-  .handlers[SERVER_HANDLER] = m_away,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_away
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_away },
+  .handlers[SERVER_HANDLER] = { .handler = m_away },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_away }
 };
 
 static void
@@ -139,7 +138,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
