@@ -21,7 +21,7 @@
 
 /*! \file m_capab.c
  * \brief Includes required functions for processing the CAPAB command.
- * \version $Id: m_capab.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -46,25 +46,26 @@
 static void
 mr_capab(struct Client *source_p, int parc, char *parv[])
 {
-  unsigned int cap = 0;
+  char *const list = parv[1];
   char *p = NULL;
 
-  for (const char *s = strtok_r(parv[1], " ", &p); s;
-                   s = strtok_r(NULL,    " ", &p))
-    if ((cap = capab_find(s)))
+  for (const char *s = strtok_r(list, " ", &p); s;
+                   s = strtok_r(NULL, " ", &p))
+  {
+    unsigned int cap = capab_find(s);
+    if (cap)
       SetCapable(source_p, cap);
+  }
 }
 
 static struct Message capab_msgtab =
 {
   .cmd = "CAPAB",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = mr_capab,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_capab, .args_min = 2 },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -81,7 +82,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
