@@ -21,7 +21,7 @@
 
 /*! \file m_dline.c
  * \brief Includes required functions for processing the DLINE command.
- * \version $Id: m_dline.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -54,24 +54,20 @@ dline_check(const struct AddressRec *arec)
 
     DLINK_FOREACH_SAFE(node, node_next, (*list)->head)
     {
-      struct Client *client_p = node->data;
+      struct Client *client = node->data;
 
-      if (IsDead(client_p))
+      if (IsDead(client))
         continue;
 
       switch (arec->masktype)
       {
-        case HM_IPV4:
-          if (client_p->ip.ss.ss_family == AF_INET)
-            if (match_ipv4(&client_p->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
-              conf_try_ban(client_p, CLIENT_BAN_DLINE, arec->conf->reason);
-          break;
         case HM_IPV6:
-          if (client_p->ip.ss.ss_family == AF_INET6)
-            if (match_ipv6(&client_p->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
-              conf_try_ban(client_p, CLIENT_BAN_DLINE, arec->conf->reason);
+        case HM_IPV4:
+          if (address_compare(&client->ip, &arec->Mask.ipa.addr, false, false, arec->Mask.ipa.bits) == true)
+            conf_try_ban(client, CLIENT_BAN_DLINE, arec->conf->reason);
           break;
-        default: break;
+        default:
+          assert(0);
       }
     }
   }
@@ -237,9 +233,6 @@ ms_dline(struct Client *source_p, int parc, char *parv[])
     .duration = strtoumax(parv[2], NULL, 10)
   };
 
-  if (parc != 5 || EmptyString(parv[parc - 1]))
-    return;
-
   sendto_match_servs(source_p, aline.server, CAPAB_DLN, "DLINE %s %ju %s :%s",
                      aline.server, aline.duration, aline.host, aline.reason);
 
@@ -255,13 +248,11 @@ ms_dline(struct Client *source_p, int parc, char *parv[])
 static struct Message dline_msgtab =
 {
   .cmd = "DLINE",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = ms_dline,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_dline
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = ms_dline, .args_min = 5 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_dline, .args_min = 2 }
 };
 
 static void
@@ -280,7 +271,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
