@@ -21,7 +21,7 @@
 
 /*! \file m_encap.c
  * \brief Includes required functions for processing the ENCAP command.
- * \version $Id: m_encap.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -43,64 +43,61 @@
 static void
 ms_encap(struct Client *source_p, int parc, char *parv[])
 {
-  char buffer[IRCD_BUFSIZE] = "", *ptr = buffer;
-  unsigned int cur_len = 0, len, i;
-#ifdef NOT_USED_YET
-  int paramcount, mpara = 0;
-#endif
-  struct Message *mptr = NULL;
+  char buf[IRCD_BUFSIZE];
+  char *bufptr = buf;
+  unsigned int cur_len = 0, len;
 
-  for (i = 1; i < (unsigned int)parc - 1; ++i)
+  for (unsigned int i = 1; i < (unsigned int)parc - 1; ++i)
   {
     len = strlen(parv[i]) + 1;  /* +1 for the space */
 
     /* Drop the whole command if this parameter would be truncated */
-    if ((cur_len + len) >= sizeof(buffer))
+    if ((cur_len + len) >= sizeof(buf))
       return;
 
-    snprintf(ptr, sizeof(buffer) - cur_len, "%s ", parv[i]);
+    snprintf(bufptr, sizeof(buf) - cur_len, "%s ", parv[i]);
     cur_len += len;
-    ptr += len;
+    bufptr += len;
   }
 
   /* If it's a command without parameters, don't prepend a ':' */
   if (parc == 3)
-    snprintf(ptr, sizeof(buffer) - cur_len, "%s", parv[2]);
+    snprintf(bufptr, sizeof(buf) - cur_len, "%s", parv[2]);
   else
-    snprintf(ptr, sizeof(buffer) - cur_len, ":%s", parv[parc - 1]);
+    snprintf(bufptr, sizeof(buf) - cur_len, ":%s", parv[parc - 1]);
 
-  sendto_match_servs(source_p, parv[1], CAPAB_ENCAP,
-                     "ENCAP %s", buffer);
+  sendto_match_servs(source_p, parv[1], CAPAB_ENCAP, "ENCAP %s", buf);
 
   if (match(parv[1], me.name))
     return;
 
-  if ((mptr = find_command(parv[2])) == NULL)
+  struct Message *message = find_command(parv[2]);
+  if (message == NULL)
     return;
 
-#ifdef NOT_USED_YET
-  paramcount = mptr->parameters;
-  mpara      = mptr->maxpara;
-#endif
-  mptr->bytes += strlen(buffer);
+  const struct MessageHandler *const handler = &message->handlers[ENCAP_HANDLER];
+  message->bytes += strlen(buf);
+  message->ecount++;
 
   parv += 2;
   parc -= 2;
 
-  if ((unsigned int)parc >= mptr->args_min)
-    mptr->handlers[ENCAP_HANDLER](source_p, parc, parv);
+  if (handler->args_min &&
+      (((unsigned int)parc < handler->args_min) ||
+       (handler->empty_last_arg != true && EmptyString(parv[handler->args_min - 1]))))
+    return;
+
+  handler->handler(source_p, parc, parv);
 }
 
 static struct Message encap_msgtab =
 {
   .cmd = "ENCAP",
-  .args_min = 3,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_encap,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_ignore },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_encap, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -119,7 +116,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
