@@ -21,7 +21,7 @@
 
 /*! \file m_hash.c
  * \brief Includes required functions for processing the HASH command.
- * \version $Id: m_hash.c 9233 2020-01-31 17:31:08Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -123,12 +123,11 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 static struct Message hash_msgtab =
 {
   .cmd = "HASH",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_hash
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_hash }
 };
 
 static void
@@ -145,7 +144,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9233 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
