@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 9320 2020-03-08 12:33:15Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -116,9 +116,9 @@ static const struct InfoStruct info_table[] =
     "Network name"
   },
   {
-    "network_desc",
+    "network_description",
     OUTPUT_STRING,
-    &ConfigServerInfo.network_desc,
+    &ConfigServerInfo.network_description,
     "Network description"
   },
   {
@@ -380,10 +380,10 @@ static const struct InfoStruct info_table[] =
     "Minimum non-wildcards in gecos bans"
   },
   {
-    "max_watch",
+    "max_monitor",
     OUTPUT_DECIMAL,
-    &ConfigGeneral.max_watch,
-    "Maximum nicknames on watch list"
+    &ConfigGeneral.max_monitor,
+    "Maximum nicknames on monitor list"
   },
   {
     "max_accept",
@@ -772,7 +772,7 @@ m_info(struct Client *source_p, int parc, char *parv[])
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s INFO :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
   send_info_text(source_p);
@@ -792,7 +792,7 @@ m_info(struct Client *source_p, int parc, char *parv[])
 static void
 ms_info(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s INFO :%s", 1, parv)->ret != HUNTED_ISME)
     return;
 
   send_info_text(source_p);
@@ -801,12 +801,11 @@ ms_info(struct Client *source_p, int parc, char *parv[])
 static struct Message info_msgtab =
 {
   .cmd = "INFO",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_info,
-  .handlers[SERVER_HANDLER] = ms_info,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_info
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_info },
+  .handlers[SERVER_HANDLER] = { .handler = ms_info },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_info }
 };
 
 static void
@@ -823,7 +822,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9320 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
