@@ -21,7 +21,7 @@
 
 /*! \file m_invite.c
  * \brief Includes required functions for processing the INVITE command.
- * \version $Id: m_invite.c 9266 2020-02-12 16:55:29Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -61,8 +61,10 @@ m_invite(struct Client *source_p, int parc, char *parv[])
     dlink_node *node;
 
     DLINK_FOREACH(node, source_p->connection->invited.head)
-      sendto_one_numeric(source_p, &me, RPL_INVITELIST,
-                         ((const struct Invite *)node->data)->channel->name);
+    {
+      const struct Invite *const invite = node->data;
+      sendto_one_numeric(source_p, &me, RPL_INVITELIST, invite->channel->name);
+    }
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFINVITELIST);
     return;
@@ -88,20 +90,20 @@ m_invite(struct Client *source_p, int parc, char *parv[])
     return;
   }
 
-  struct ChannelMember *member = find_channel_link(source_p, channel);
+  struct ChannelMember *member = member_find_link(source_p, channel);
   if (member == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, channel->name);
     return;
   }
 
-  if (!has_member_flags(member, CHFL_CHANOP | CHFL_HALFOP))
+  if (member_has_flags(member, CHFL_CHANOP | CHFL_HALFOP) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, channel->name);
     return;
   }
 
-  if (IsMember(target_p, channel))
+  if (member_find_link(target_p, channel))
   {
     sendto_one_numeric(source_p, &me, ERR_USERONCHANNEL, target_p->name, channel->name);
     return;
@@ -174,9 +176,6 @@ m_invite(struct Client *source_p, int parc, char *parv[])
 static void
 ms_invite(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc < 3 || EmptyString(parv[2]))
-    return;
-
   struct Client *target_p = find_person(source_p, parv[1]);
   if (target_p == NULL)
     return;
@@ -185,12 +184,11 @@ ms_invite(struct Client *source_p, int parc, char *parv[])
   if (channel == NULL)
     return;
 
-  if (IsMember(target_p, channel))
+  if (member_find_link(target_p, channel))
     return;
 
-  if (parc > 3 && IsDigit(*parv[3]))
-    if (strtoumax(parv[3], NULL, 10) > channel->creation_time)
-      return;
+  if (strtoumax(parv[3], NULL, 10) > channel->creation_time)
+    return;
 
   channel->last_invite_time = event_base->time.sec_monotonic;
 
@@ -224,13 +222,11 @@ ms_invite(struct Client *source_p, int parc, char *parv[])
 static struct Message invite_msgtab =
 {
   .cmd = "INVITE",
-  .args_max = MAXPARA,
-  .flags = MFLG_ENDGRACE,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_invite,
-  .handlers[SERVER_HANDLER] = ms_invite,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_invite
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_invite, .end_grace_period = true },
+  .handlers[SERVER_HANDLER] = { .handler = ms_invite, .args_min = 4 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_invite, .end_grace_period = true }
 };
 
 static void
@@ -247,7 +243,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9266 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
