@@ -21,7 +21,7 @@
 
 /*! \file m_ison.c
  * \brief Includes required functions for processing the ISON command.
- * \version $Id: m_ison.c 9349 2020-04-26 05:59:56Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -78,13 +78,11 @@ m_ison(struct Client *source_p, int parc, char *parv[])
 static struct Message ison_msgtab =
 {
   .cmd = "ISON",
-  .args_min = 2,
-  .args_max = 1,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_ison,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ison
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ison, .args_min = 2, .args_max = 1 },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ison, .args_min = 2, .args_max = 1 }
 };
 
 static void
@@ -101,7 +99,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9349 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
