@@ -21,7 +21,7 @@
 
 /*! \file m_knock.c
  * \brief Includes required functions for processing the KNOCK command.
- * \version $Id: m_knock.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -58,12 +58,6 @@ m_knock(struct Client *source_p, int parc, char *parv[])
 {
   const char *const name = parv[1];
 
-  if (EmptyString(name))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "KNOCK");
-    return;
-  }
-
   struct Channel *channel = hash_find_channel(name);
   if (channel == NULL)
   {
@@ -72,7 +66,7 @@ m_knock(struct Client *source_p, int parc, char *parv[])
   }
 
   /* Normal channel, just be sure they aren't on it. */
-  if (IsMember(source_p, channel))
+  if (member_find_link(source_p, channel))
   {
     sendto_one_numeric(source_p, &me, ERR_KNOCKONCHAN, channel->name);
     return;
@@ -88,6 +82,12 @@ m_knock(struct Client *source_p, int parc, char *parv[])
 
   if (MyClient(source_p))
   {
+    if (HasCMode(channel, MODE_NOKNOCK))
+    {
+      sendto_one_numeric(source_p, &me, ERR_CANNOTKNOCK, channel->name);
+      return;
+    }
+
     /*
      * Don't allow a knock if the user is banned, or the channel is private.
      */
@@ -133,13 +133,11 @@ m_knock(struct Client *source_p, int parc, char *parv[])
 static struct Message knock_msgtab =
 {
   .cmd = "KNOCK",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_knock,
-  .handlers[SERVER_HANDLER] = m_knock,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_knock
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_knock, .args_min = 2 },
+  .handlers[SERVER_HANDLER] = { .handler = m_knock, .args_min = 2 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_knock, .args_min = 2 }
 };
 
 static void
@@ -160,7 +158,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
