@@ -21,7 +21,7 @@
 
 /*! \file m_links.c
  * \brief Includes required functions for processing the LINKS command.
- * \version $Id: m_links.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -42,7 +42,7 @@
  * \param source_p Pointer to client to report to
  */
 static void
-do_links(struct Client *source_p, int parc, char *parv[])
+do_links(struct Client *source_p, char *parv[])
 {
   dlink_node *node;
 
@@ -54,7 +54,9 @@ do_links(struct Client *source_p, int parc, char *parv[])
 
   if (HasUMode(source_p, UMODE_OPER) || ConfigServerHide.flatten_links == 0)
   {
-    const char *mask = (parc > 2 ? parv[2] : parv[1]);
+    const char *mask = parv[2];
+    if (EmptyString(mask))
+      mask = parv[1];
 
     DLINK_FOREACH(node, global_server_list.head)
     {
@@ -101,7 +103,7 @@ do_links(struct Client *source_p, int parc, char *parv[])
 static void
 mo_links(struct Client *source_p, int parc, char *parv[])
 {
-  do_links(source_p, parc, parv);
+  do_links(source_p, parv);
 }
 
 /*! \brief LINKS command handler
@@ -132,18 +134,17 @@ m_links(struct Client *source_p, int parc, char *parv[])
 
   last_used = event_base->time.sec_monotonic;
 
-  do_links(source_p, parc, parv);
+  do_links(source_p, parv);
 }
 
 static struct Message links_msgtab =
 {
   .cmd = "LINKS",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_links,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_links
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_links },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_links }
 };
 
 static void
@@ -160,7 +161,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
