@@ -21,7 +21,7 @@
 
 /*! \file m_list.c
  * \brief Includes required functions for processing the LIST command.
- * \version $Id: m_list.c 9334 2020-04-18 16:18:49Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -184,12 +184,11 @@ m_list(struct Client *source_p, int parc, char *parv[])
 static struct Message list_msgtab =
 {
   .cmd = "LIST",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_list,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_list
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_list },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_list },
 };
 
 static void
@@ -210,7 +209,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9334 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
