@@ -21,7 +21,7 @@
 
 /*! \file m_names.c
  * \brief Includes required functions for processing the NAMES command.
- * \version $Id: m_names.c 9112 2020-01-04 15:50:08Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -57,7 +57,7 @@ m_names(struct Client *source_p, int parc, char *parv[])
   {
     struct Channel *channel = hash_find_channel(name);
     if (channel)
-      channel_member_names(source_p, channel, true);
+      channel_send_namereply(source_p, channel);
     else
       sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, name);
   }
@@ -68,12 +68,11 @@ m_names(struct Client *source_p, int parc, char *parv[])
 static struct Message names_msgtab =
 {
   .cmd = "NAMES",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_names,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_names
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_names },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_names }
 };
 
 static void
@@ -90,7 +89,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9112 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
