@@ -21,7 +21,7 @@
 
 /*! \file m_oper.c
  * \brief Includes required functions for processing the OPER command.
- * \version $Id: m_oper.c 9334 2020-04-18 16:18:49Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -79,8 +79,9 @@ oper_up(struct Client *source_p, const struct MaskItem *conf)
                   RPL_WHOISOPERATOR, conf->whois);
   }
 
-  ilog(LOG_TYPE_OPER, "OPER %s by %s!%s@%s", conf->name, source_p->name,
-       source_p->username, source_p->host);
+  ilog(LOG_TYPE_OPER, "OPER %s by %s",
+       conf->name, client_get_name(source_p, HIDE_IP));
+
   sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "%s is now an operator",
                        get_oper_name(source_p));
   sendto_server(NULL, 0, 0, ":%s GLOBOPS :%s is now an operator",
@@ -102,13 +103,11 @@ failed_oper_notice(struct Client *source_p, const char *name,
 {
   if (ConfigGeneral.failed_oper_notice)
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "Failed OPER attempt as %s by %s (%s@%s) - %s",
-                         name, source_p->name, source_p->username,
-                         source_p->host, reason);
+                         "Failed OPER attempt as %s by %s - %s",
+                         name, client_get_name(source_p, HIDE_IP), reason);
 
-  ilog(LOG_TYPE_OPER, "Failed OPER attempt as %s by %s (%s@%s) - %s",
-       name, source_p->name, source_p->username,
-       source_p->host, reason);
+  ilog(LOG_TYPE_OPER, "Failed OPER attempt as %s by %s - %s",
+       name, client_get_name(source_p, HIDE_IP), reason);
 }
 
 /*! \brief OPER command handler
@@ -129,12 +128,6 @@ m_oper(struct Client *source_p, int parc, char *parv[])
   const char *const opername = parv[1];
   const char *const password = parv[2];
 
-  if (EmptyString(password))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "OPER");
-    return;
-  }
-
   struct MaskItem *conf = operator_find(source_p, opername);
   if (conf == NULL)
   {
@@ -154,7 +147,7 @@ m_oper(struct Client *source_p, int parc, char *parv[])
 
   if (!EmptyString(conf->certfp))
   {
-    if (EmptyString(source_p->certfp) || strcasecmp(source_p->certfp, conf->certfp))
+    if (EmptyString(source_p->tls_certfp) || strcasecmp(source_p->tls_certfp, conf->certfp))
     {
       sendto_one_numeric(source_p, &me, ERR_NOOPERHOST);
       failed_oper_notice(source_p, opername, "client certificate fingerprint mismatch");
@@ -162,22 +155,21 @@ m_oper(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if (match_conf_password(password, conf) == true)
-  {
-    if (conf_attach(source_p, conf))
-    {
-      sendto_one_notice(source_p, &me, ":Can't attach conf!");
-      failed_oper_notice(source_p, opername, "can't attach conf!");
-      return;
-    }
-
-    oper_up(source_p, conf);
-  }
-  else
+  if (match_conf_password(password, conf) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_PASSWDMISMATCH);
     failed_oper_notice(source_p, opername, "password mismatch");
+    return;
   }
+
+  if (conf_attach(source_p, conf))
+  {
+    sendto_one_notice(source_p, &me, ":Can't attach conf!");
+    failed_oper_notice(source_p, opername, "can't attach conf!");
+    return;
+  }
+
+  oper_up(source_p, conf);
 }
 
 /*! \brief OPER command handler
@@ -201,14 +193,11 @@ mo_oper(struct Client *source_p, int parc, char *parv[])
 static struct Message oper_msgtab =
 {
   .cmd = "OPER",
-  .args_min = 3,
-  .args_max = MAXPARA,
-  .flags = MFLG_ENDGRACE,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_oper
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_oper, .args_min = 3, .end_grace_period = true },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_oper, .args_min = 3, .end_grace_period = true }
 };
 
 static void
@@ -225,7 +214,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9334 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
