@@ -21,7 +21,7 @@
 
 /*! \file m_pass.c
  * \brief Includes required functions for processing the PASS command.
- * \version $Id: m_pass.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -54,16 +54,11 @@
 static void
 mr_pass(struct Client *source_p, int parc, char *parv[])
 {
+  const char *const password = parv[1];
   assert(MyConnect(source_p));
 
-  if (EmptyString(parv[1]))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "PASS");
-    return;
-  }
-
-  xfree(source_p->connection->password);
-  source_p->connection->password = xstrndup(parv[1], IRCD_MIN(strlen(parv[1]), PASSWDLEN));
+  if (source_p->connection->password == NULL)
+    source_p->connection->password = xstrndup(password, IRCD_MIN(strlen(password), PASSWDLEN));
 
   /* Only do this stuff if we are doing ts6 */
   if (parc > 4)
@@ -74,13 +69,11 @@ mr_pass(struct Client *source_p, int parc, char *parv[])
 static struct Message pass_msgtab =
 {
   .cmd = "PASS",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = mr_pass,
-  .handlers[CLIENT_HANDLER] = m_registered,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_registered
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_pass, .args_min = 2 },
+  .handlers[CLIENT_HANDLER] = { .handler = m_registered },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_registered }
 };
 
 static void
@@ -97,7 +90,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
