@@ -21,7 +21,7 @@
 
 /*! \file m_set.c
  * \brief Includes required functions for processing the SET command.
- * \version $Id: m_set.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -41,6 +41,11 @@
 static void
 quote_autoconn(struct Client *source_p, const char *arg, int newval)
 {
+  static const char *const status[] =
+  {
+    "OFF", "ON"
+  };
+
   if (EmptyString(arg))
   {
     sendto_one_notice(source_p, &me, ":Please specify a server name!");
@@ -60,10 +65,10 @@ quote_autoconn(struct Client *source_p, const char *arg, int newval)
     ClearConfAllowAutoConn(conf);
 
   sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                       "%s has changed AUTOCONN for %s to %i",
-                       get_oper_name(source_p), conf->name, newval);
-  sendto_one_notice(source_p, &me, ":AUTOCONN for %s is now set to %i",
-                    conf->name, newval);
+                       "%s has changed AUTOCONN for %s to %s",
+                       get_oper_name(source_p), conf->name, status[newval != 0]);
+  sendto_one_notice(source_p, &me, ":AUTOCONN for %s is now set to %s",
+                    conf->name, status[newval != 0]);
 }
 
 /* SET AUTOCONNALL */
@@ -158,11 +163,11 @@ quote_spamnum(struct Client *source_p, const char *arg, int newval)
 
     GlobalSetOptions.spam_num = IRCD_MAX(newval, MIN_SPAM_NUM);
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed SPAMNUM to %i",
+                         "%s has changed SPAMNUM to %u",
                          get_oper_name(source_p), GlobalSetOptions.spam_num);
   }
   else
-    sendto_one_notice(source_p, &me, ":SPAMNUM is currently %i",
+    sendto_one_notice(source_p, &me, ":SPAMNUM is currently %u",
                       GlobalSetOptions.spam_num);
 }
 
@@ -372,12 +377,11 @@ mo_set(struct Client *source_p, int parc, char *parv[])
 static struct Message set_msgtab =
 {
   .cmd = "SET",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_not_oper,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_set
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_not_oper },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_set }
 };
 
 static void
@@ -394,7 +398,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
