@@ -21,7 +21,7 @@
 
 /*! \file m_stats.c
  * \brief Includes required functions for processing the STATS command.
- * \version $Id: m_stats.c 9321 2020-03-08 12:40:32Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -49,7 +49,7 @@
 #include "event.h"
 #include "modules.h"
 #include "whowas.h"
-#include "watch.h"
+#include "monitor.h"
 #include "reslib.h"
 #include "motd.h"
 #include "ipcache.h"
@@ -349,9 +349,9 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   size_t local_client_memory_used  = 0;
   size_t remote_client_memory_used = 0;
 
-  unsigned int watch_list_headers = 0;   /* watchlist headers     */
-  unsigned int watch_list_entries = 0;   /* watchlist entries     */
-  size_t watch_list_memory = 0; /* watchlist memory used */
+  unsigned int monitor_list_headers = 0;   /* monitorlist headers     */
+  unsigned int monitor_list_entries = 0;   /* monitorlist entries     */
+  size_t monitor_list_memory = 0; /* monitorlist memory used */
 
   unsigned int listener_count = 0;
   size_t listener_memory = 0;
@@ -369,7 +369,7 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
     const struct Client *target_p = node->data;
 
     local_client_conf_count += dlink_list_length(&target_p->connection->confs);
-    watch_list_entries += dlink_list_length(&target_p->connection->watches);
+    monitor_list_entries += dlink_list_length(&target_p->connection->monitors);
   }
 
   local_client_count = dlink_list_length(&local_server_list) + dlink_list_length(&local_client_list);
@@ -410,13 +410,13 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  watch_count_memory(&watch_list_headers, &watch_list_memory);
+  monitor_count_memory(&monitor_list_headers, &monitor_list_memory);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :WATCH headers %u(%zu) entries %u(%zu)",
-                     watch_list_headers,
-                     watch_list_memory,
-                     watch_list_entries,
-                     watch_list_entries * sizeof(dlink_node) * 2);
+                     "z :MONITOR headers %u(%zu) entries %u(%zu)",
+                     monitor_list_headers,
+                     monitor_list_memory,
+                     monitor_list_entries,
+                     monitor_list_entries * sizeof(dlink_node) * 2);
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Clients %u(%zu)",
@@ -898,28 +898,32 @@ stats_ports(struct Client *source_p, int parc, char *parv[])
     char *p = buf;
     const struct Listener *listener = node->data;
 
-    if (listener->flags & LISTENER_HIDDEN)
+    if (listener_has_flag(listener, LISTENER_HIDDEN))
     {
       if (!HasUMode(source_p, UMODE_ADMIN))
         continue;
       *p++ = 'H';
     }
 
-    if (listener->flags & LISTENER_SERVER)
+    if (listener_has_flag(listener, LISTENER_SERVER))
       *p++ = 'S';
-    if (listener->flags & LISTENER_TLS)
+    if (listener_has_flag(listener, LISTENER_CLIENT))
+      *p++ = 'C';
+    if (listener_has_flag(listener, LISTENER_TLS))
       *p++ = 'T';
+    if (listener_has_flag(listener, LISTENER_DEFER))
+      *p++ = 'D';
     *p = '\0';
 
     if (HasUMode(source_p, UMODE_ADMIN) && ConfigServerHide.hide_server_ips == 0)
       sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
                          listener->name,
                          listener->ref_count, buf,
-                         listener->active ? "active" : "disabled");
+                         listener->active == true ? "active" : "disabled");
     else
       sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
                          me.name, listener->ref_count, buf,
-                         listener->active ? "active" : "disabled");
+                         listener->active == true ? "active" : "disabled");
   }
 }
 
@@ -1059,20 +1063,10 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
   dlink_node *node;
   uintmax_t sendB = 0, recvB = 0;
 
-  if (ConfigServerHide.flatten_links && !HasUMode(source_p, UMODE_OPER))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
-    return;
-  }
-
   DLINK_FOREACH(node, local_server_list.head)
   {
     const struct Client *target_p = node->data;
 
-    if (HasFlag(target_p, FLAGS_SERVICE) && ConfigServerHide.hide_services)
-      if (!HasUMode(source_p, UMODE_OPER))
-        continue;
-
     sendB += target_p->connection->send.bytes;
     recvB += target_p->connection->recv.bytes;
 
@@ -1086,7 +1080,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
                target_p->connection->recv.bytes >> 10,
                (event_base->time.sec_monotonic - target_p->connection->created_monotonic),
                (event_base->time.sec_monotonic - target_p->connection->last_data),
-               HasUMode(source_p, UMODE_OPER) ? capab_get(target_p) : "TS");
+               capab_get(target_p));
   }
 
   sendB >>= 10;
@@ -1099,7 +1093,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT, "? :Recv total: %7.2f %s",
                      _GMKv(recvB), _GMKs(recvB));
 
-  uintmax_t uptime = (event_base->time.sec_monotonic - me.connection->created_monotonic);
+  const uintmax_t uptime = (event_base->time.sec_monotonic - me.connection->created_monotonic);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "? :Server send: %7.2f %s (%4.1f KiB/s)",
                      _GMKv((me.connection->send.bytes >> 10)),
@@ -1128,21 +1122,18 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
 static const char *
 parse_stats_args(struct Client *source_p, int parc, char *parv[], bool *doall, bool *wilds)
 {
-  if (parc > 2)
-  {
-    const char *name = parv[2];
+  const char *const name = parv[2];
 
-    if (irccmp(name, ID_or_name(&me, source_p)) == 0)
-      *doall = true;
-    else if (match(name, ID_or_name(&me, source_p)) == 0)
-      *doall = true;
+  if (EmptyString(name))
+    return NULL;
 
-    *wilds = has_wildcards(name);
+  if (irccmp(name, ID_or_name(&me, source_p)) == 0)
+    *doall = true;
+  else if (match(name, ID_or_name(&me, source_p)) == 0)
+    *doall = true;
 
-    return name;
-  }
-
-  return NULL;
+  *wilds = has_wildcards(name);
+  return name;
 }
 
 static void
@@ -1270,7 +1261,7 @@ static const struct StatsStruct  stats_tab[] =
   { .letter = 'y', .handler = stats_class, .required_modes = UMODE_OPER },
   { .letter = 'Y', .handler = stats_class, .required_modes = UMODE_OPER },
   { .letter = 'z', .handler = stats_memory, .required_modes = UMODE_OPER },
-  { .letter = '?', .handler = stats_servlinks },
+  { .letter = '?', .handler = stats_servlinks, .required_modes = UMODE_OPER },
   { .letter = '\0' }
 };
 
@@ -1324,7 +1315,7 @@ m_stats(struct Client *source_p, int parc, char *parv[])
 
   /* Is the stats meant for us? */
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s STATS %s :%s", 2, parv)->ret != HUNTED_ISME)
       return;
 
   do_stats(source_p, parc, parv);
@@ -1339,7 +1330,7 @@ m_stats(struct Client *source_p, int parc, char *parv[])
 static void
 ms_stats(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s STATS %s :%s", 2, parv)->ret != HUNTED_ISME)
     return;
 
   do_stats(source_p, parc, parv);
@@ -1355,13 +1346,11 @@ stats_init(void)
 static struct Message stats_msgtab =
 {
   .cmd = "STATS",
-  .args_min = 2,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_stats,
-  .handlers[SERVER_HANDLER] = ms_stats,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_stats
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_stats, .args_min = 2 },
+  .handlers[SERVER_HANDLER] = { .handler = ms_stats, .args_min = 3 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_stats, .args_min = 2 }
 };
 
 static void
@@ -1379,7 +1368,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9321 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
