@@ -21,7 +21,7 @@
 
 /*! \file m_svstag.c
  * \brief Includes required functions for processing the SVSTAG command.
- * \version $Id: m_svstag.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -64,17 +64,16 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
   if (ts && (ts != target_p->tsinfo))
     return;
 
-  if (strncmp(parv[3], "-", 1) == 0)
+  if (strcmp(parv[3], "-") == 0)
   {
-    /* TBD: possibly allow to remove certain tags by numeric */
     svstag_clear_list(&target_p->svstags);
-    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju %s",
+    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju -",
                   source_p->id,
-                  target_p->id, target_p->tsinfo, parv[3]);
+                  target_p->id, target_p->tsinfo);
     return;
   }
 
-  if (parc < 6 || EmptyString(parv[5]))
+  if (EmptyString(parv[5]))
     return;
 
   svstag_attach(&target_p->svstags, strtoul(parv[3], NULL, 10), parv[4], parv[5]);
@@ -88,13 +87,11 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
 static struct Message svstag_msgtab =
 {
   .cmd = "SVSTAG",
-  .args_min = 4,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_ignore,
-  .handlers[CLIENT_HANDLER] = m_ignore,
-  .handlers[SERVER_HANDLER] = ms_svstag,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_ignore
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_ignore },
+  .handlers[SERVER_HANDLER] = { .handler = ms_svstag, .args_min = 4 },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_ignore }
 };
 
 static void
@@ -111,7 +108,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
