@@ -21,7 +21,7 @@
 
 /*! \file m_trace.c
  * \brief Includes required functions for processing the TRACE command.
- * \version $Id: m_trace.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -200,10 +200,10 @@ static void
 mo_trace(struct Client *source_p, int parc, char *parv[])
 {
   if (parc > 2)
-    if (server_hunt(source_p, ":%s TRACE %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s TRACE %s :%s", 2, parv)->ret != HUNTED_ISME)
       return;
 
-  const struct server_hunt *hunt = server_hunt(source_p, ":%s TRACE :%s", 1, parc, parv);
+  const struct server_hunt *hunt = server_hunt(source_p, ":%s TRACE :%s", 1, parv);
   switch (hunt->ret)
   {
     case HUNTED_PASS:
@@ -221,12 +221,11 @@ mo_trace(struct Client *source_p, int parc, char *parv[])
 static struct Message trace_msgtab =
 {
   .cmd = "TRACE",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_trace,
-  .handlers[SERVER_HANDLER] = mo_trace,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = mo_trace
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_trace },
+  .handlers[SERVER_HANDLER] = { .handler = mo_trace },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = mo_trace }
 };
 
 static void
@@ -243,7 +242,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
