@@ -21,7 +21,7 @@
 
 /*! \file m_user.c
  * \brief Includes required functions for processing the USER command.
- * \version $Id: m_user.c 9360 2020-04-29 14:02:24Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -36,30 +36,6 @@
 #include "listener.h"
 
 
-/* do_user()
- *
- * inputs       -
- * output       - NONE
- * side effects -
- */
-static void
-do_user(struct Client *source_p,
-        const char *username,
-        const char *realname)
-{
-  assert(IsUnknown(source_p));
-
-  source_p->connection->registration &= ~REG_NEED_USER;
-
-  strlcpy(source_p->info, realname, sizeof(source_p->info));
-
-  if (!HasFlag(source_p, FLAGS_GOTID))
-    strlcpy(source_p->username, username, sizeof(source_p->username));
-
-  if (source_p->connection->registration == 0)
-    register_local_user(source_p);
-}
-
 /*! \brief USER command handler
  *
  * \param source_p Pointer to allocated Client struct from which the message
@@ -80,35 +56,38 @@ mr_user(struct Client *source_p, int parc, char *parv[])
   const char *const username = parv[1];
   const char *const realname = parv[4];
 
-  if (source_p->connection->listener->flags & LISTENER_SERVER)
+  assert(IsUnknown(source_p));
+
+  if (listener_has_flag(source_p->connection->listener, LISTENER_SERVER) == true)
   {
     exit_client(source_p, "Use a different port");
     return;
   }
 
-  if (EmptyString(realname))
+  if (!HasFlag(source_p, FLAGS_GOTID))
   {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "USER");
-    return;
+    char *p = strchr(username, '@');
+    if (p)
+      *p = '\0';
+
+    strlcpy(source_p->username, username, sizeof(source_p->username));
   }
 
-  char *p = strchr(username, '@');
-  if (p)
-    *p = '\0';
+  strlcpy(source_p->info, realname, sizeof(source_p->info));
+  source_p->connection->registration &= ~REG_NEED_USER;
 
-  do_user(source_p, username, realname);
+  if (source_p->connection->registration == 0)
+    register_local_user(source_p);
 }
 
 static struct Message user_msgtab =
 {
   .cmd = "USER",
-  .args_min = 5,
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = mr_user,
-  .handlers[CLIENT_HANDLER] = m_registered,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_registered
+  .handlers[UNREGISTERED_HANDLER] = { .handler = mr_user, .args_min = 5 },
+  .handlers[CLIENT_HANDLER] = { .handler = m_registered },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_registered }
 };
 
 static void
@@ -125,7 +104,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9360 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
