@@ -21,7 +21,7 @@
 
 /*! \file m_version.c
  * \brief Includes required functions for processing the VERSION command.
- * \version $Id: m_version.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -36,7 +36,6 @@
 #include "modules.h"
 #include "isupport.h"
 #include "patchlevel.h"
-#include "serno.h"
 
 
 /* Option string. */
@@ -79,11 +78,10 @@ m_version(struct Client *source_p, int parc, char *parv[])
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s VERSION :%s", 1, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s VERSION :%s", 1, parv)->ret != HUNTED_ISME)
       return;
 
-  sendto_one_numeric(source_p, &me, RPL_VERSION, PATCHLEVEL, SERIALNUM,
-                     me.name, serveropts);
+  sendto_one_numeric(source_p, &me, RPL_VERSION, PATCHLEVEL, me.name, serveropts);
   isupport_show(source_p);
 }
 
@@ -101,23 +99,21 @@ m_version(struct Client *source_p, int parc, char *parv[])
 static void
 ms_version(struct Client *source_p, int parc, char *parv[])
 {
-  if (server_hunt(source_p, ":%s VERSION :%s", 1, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s VERSION :%s", 1, parv)->ret != HUNTED_ISME)
     return;
 
-  sendto_one_numeric(source_p, &me, RPL_VERSION, PATCHLEVEL, SERIALNUM,
-                     me.name, serveropts);
+  sendto_one_numeric(source_p, &me, RPL_VERSION, PATCHLEVEL, me.name, serveropts);
   isupport_show(source_p);
 }
 
 static struct Message version_msgtab =
 {
   .cmd = "VERSION",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_version,
-  .handlers[SERVER_HANDLER] = ms_version,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_version
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_version },
+  .handlers[SERVER_HANDLER] = { .handler = ms_version },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_version }
 };
 
 static void
@@ -134,7 +130,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9102 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
