@@ -21,7 +21,7 @@
 
 /*! \file m_who.c
  * \brief Includes required functions for processing the WHO command.
- * \version $Id: m_who.c 9276 2020-02-12 19:14:18Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -38,6 +38,7 @@
 #include "conf.h"
 #include "parse.h"
 #include "modules.h"
+#include "hostmask.h"
 
 
 enum { WHO_MAX_REPLIES = 500 };
@@ -56,14 +57,16 @@ static void
 do_who(struct Client *source_p, const struct Client *target_p,
        const char *name, const char *op_flags)
 {
-  char status[8] = "";  /* sizeof("Gr*@%+") + 2 */
+  char status[8];  /* sizeof("GBr*@%+") + 1 */
 
   if (HasUMode(source_p, UMODE_OPER))
-    snprintf(status, sizeof(status), "%c%s%s%s", target_p->away[0] ? 'G' : 'H',
+    snprintf(status, sizeof(status), "%c%s%s%s%s", target_p->away[0] ? 'G' : 'H',
+             HasUMode(target_p, UMODE_BOT) ? "B" : "",
              HasUMode(target_p, UMODE_REGISTERED) ? "r" : "",
              HasUMode(target_p, UMODE_OPER) ? "*" : "", op_flags);
   else
-    snprintf(status, sizeof(status), "%c%s%s%s", target_p->away[0] ? 'G' : 'H',
+    snprintf(status, sizeof(status), "%c%s%s%s%s", target_p->away[0] ? 'G' : 'H',
+             HasUMode(target_p, UMODE_BOT) ? "B" : "",
              HasUMode(target_p, UMODE_REGISTERED) ? "r" : "",
              HasUMode(target_p, UMODE_OPER) &&
              !HasUMode(target_p, UMODE_HIDDEN) ? "*" : "", op_flags);
@@ -108,6 +111,17 @@ who_matches(struct Client *source_p, struct Client *target_p, const char *mask)
 
   if (HasUMode(source_p, UMODE_OPER))
   {
+    int bits = 0;
+    struct irc_ssaddr addr;
+
+    switch (parse_netmask(mask, &addr, &bits))
+    {
+      case HM_IPV6:
+      case HM_IPV4:
+        if (address_compare(&target_p->ip, &addr, false, false, bits) == true)
+          return true;
+    }
+
     if (match(mask, target_p->sockhost) == 0)
       return true;
     if (match(mask, target_p->realhost) == 0)
@@ -265,7 +279,7 @@ do_who_on_channel(struct Client *source_p, struct Channel *channel,
         if (!HasUMode(target_p, UMODE_OPER) ||
             (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER)))
           continue;
-      do_who(source_p, target_p, channel->name, get_member_status(member, !!HasCap(source_p, CAP_MULTI_PREFIX)));
+      do_who(source_p, target_p, channel->name, member_get_prefix(member, !!HasCap(source_p, CAP_MULTI_PREFIX)));
     }
   }
 }
@@ -288,8 +302,8 @@ m_who(struct Client *source_p, int parc, char *parv[])
   dlink_node *node;
   struct Client *target_p = NULL;
   struct Channel *channel = NULL;
-  char *mask = parv[1];
-  const bool server_oper = parc > 2 && *parv[2] == 'o';  /* Show OPERS only */
+  char *const mask = parv[1];
+  const bool server_oper = parv[2] && *parv[2] == 'o';  /* Show OPERS only */
 
   /* See if mask is there, collapse it or return if not there */
   if (EmptyString(mask))
@@ -308,7 +322,7 @@ m_who(struct Client *source_p, int parc, char *parv[])
     /* List all users on a given channel */
     if ((channel = hash_find_channel(mask)))
     {
-      if (HasUMode(source_p, UMODE_ADMIN) || IsMember(source_p, channel))
+      if (HasUMode(source_p, UMODE_ADMIN) || member_find_link(source_p, channel))
         do_who_on_channel(source_p, channel, true, server_oper);
       else if (!SecretChannel(channel))
         do_who_on_channel(source_p, channel, false, server_oper);
@@ -325,13 +339,13 @@ m_who(struct Client *source_p, int parc, char *parv[])
     DLINK_FOREACH(node, target_p->channel.head)
     {
       channel = ((struct ChannelMember *)node->data)->channel;
-      if (PubChannel(channel) || IsMember(source_p, channel))
+      if (PubChannel(channel) || member_find_link(source_p, channel))
         break;
     }
 
     if (node)
       do_who(source_p, target_p, channel->name,
-             get_member_status(node->data, !!HasCap(source_p, CAP_MULTI_PREFIX)));
+             member_get_prefix(node->data, !!HasCap(source_p, CAP_MULTI_PREFIX)));
     else
       do_who(source_p, target_p, NULL, "");
 
@@ -365,12 +379,11 @@ m_who(struct Client *source_p, int parc, char *parv[])
 static struct Message who_msgtab =
 {
   .cmd = "WHO",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_who,
-  .handlers[SERVER_HANDLER] = m_ignore,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = m_who
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_who },
+  .handlers[SERVER_HANDLER] = { .handler = m_ignore },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = m_who }
 };
 
 static void
@@ -387,7 +400,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9276 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
