@@ -21,7 +21,7 @@
 
 /*! \file m_whowas.c
  * \brief Includes required functions for processing the WHOWAS command.
- * \version $Id: m_whowas.c 9199 2020-01-23 17:49:06Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -43,12 +43,12 @@
 enum { WHOWAS_MAX_REPLIES = 20 };  /* Only applies to remote clients */
 
 static void
-do_whowas(struct Client *source_p, const int parc, char *parv[])
+do_whowas(struct Client *source_p, char *parv[])
 {
   int count = 0, max = -1;
   dlink_node *node;
 
-  if (parc > 2 && !EmptyString(parv[2]))
+  if (!EmptyString(parv[2]))
     max = atoi(parv[2]);
 
   if (!MyConnect(source_p) && (max <= 0 || max > WHOWAS_MAX_REPLIES))
@@ -109,7 +109,7 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
     return;
@@ -124,10 +124,10 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
-    if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv)->ret != HUNTED_ISME)
+    if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parv)->ret != HUNTED_ISME)
       return;
 
-  do_whowas(source_p, parc, parv);
+  do_whowas(source_p, parv);
 }
 
 /*! \brief WHOWAS command handler
@@ -146,27 +146,26 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
 static void
 ms_whowas(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
     return;
   }
 
-  if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv)->ret != HUNTED_ISME)
+  if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parv)->ret != HUNTED_ISME)
     return;
 
-  do_whowas(source_p, parc, parv);
+  do_whowas(source_p, parv);
 }
 
 static struct Message whowas_msgtab =
 {
   .cmd = "WHOWAS",
-  .args_max = MAXPARA,
-  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
-  .handlers[CLIENT_HANDLER] = m_whowas,
-  .handlers[SERVER_HANDLER] = ms_whowas,
-  .handlers[ENCAP_HANDLER] = m_ignore,
-  .handlers[OPER_HANDLER] = ms_whowas
+  .handlers[UNREGISTERED_HANDLER] = { .handler = m_unregistered },
+  .handlers[CLIENT_HANDLER] = { .handler = m_whowas },
+  .handlers[SERVER_HANDLER] = { .handler = ms_whowas },
+  .handlers[ENCAP_HANDLER] = { .handler = m_ignore },
+  .handlers[OPER_HANDLER] = { .handler = ms_whowas }
 };
 
 static void
@@ -183,7 +182,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9199 $",
+  .version = "$Revision$",
   .modinit = module_init,
   .modexit = module_exit,
 };
