@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 9364 2020-04-30 19:24:10Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -92,7 +92,7 @@ add_user_to_channel(struct Channel *channel, struct Client *client,
       if (!IsSetJoinFloodNoticed(channel))
       {
         SetJoinFloodNoticed(channel);
-        sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
+        sendto_realops_flags(UMODE_FLOOD, L_ALL, SEND_NOTICE,
                              "Possible Join Flooder %s on %s target: %s",
                              client_get_name(client, HIDE_IP),
                              client->servptr->name, channel->name);
@@ -138,6 +138,65 @@ remove_user_from_channel(struct ChannelMember *member)
     channel_free(channel);
 }
 
+/* remove_a_mode()
+ *
+ * inputs       -
+ * output       - NONE
+ * side effects - remove ONE mode from a channel
+ */
+void
+channel_demote_members(struct Channel *channel, const struct Client *client, unsigned int mask, const char flag)
+{
+  dlink_node *node;
+  char modebuf[MODEBUFLEN];
+  char parabuf[MODEBUFLEN];
+  char *mbuf = modebuf;
+  char *pbuf = parabuf;
+  const char *names[MAXMODEPARAMS];
+  static const unsigned int names_size = sizeof(names) / sizeof(names[0]);
+  unsigned int count = 0;
+
+  DLINK_FOREACH(node, channel->members.head)
+  {
+    struct ChannelMember *member = node->data;
+
+    if ((member->flags & mask) == 0)
+      continue;
+
+    member->flags &= ~mask;
+
+    names[count++] = member->client->name;
+
+    *mbuf++ = flag;
+
+    if (count >= names_size)
+    {
+      *mbuf = '\0';
+
+      for (unsigned int i = 0; i < names_size; ++i)
+        pbuf += snprintf(pbuf, sizeof(parabuf) - (pbuf - parabuf), " %s", names[i]);
+
+      sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s -%s%s",
+                           client->name, channel->name, modebuf, parabuf);
+      mbuf = modebuf;
+      pbuf = parabuf;
+      count = 0;
+    }
+  }
+
+  if (count)
+  {
+    assert(count < names_size);
+    *mbuf = '\0';
+
+    for (unsigned int i = 0; i < count; ++i)
+      pbuf += snprintf(pbuf, sizeof(parabuf) - (pbuf - parabuf), " %s", names[i]);
+
+    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s -%s%s",
+                         client->name, channel->name, modebuf, parabuf);
+  }
+}
+
 /* channel_send_members()
  *
  * inputs       -
@@ -162,36 +221,20 @@ channel_send_members(struct Client *client, const struct Channel *channel,
     const struct ChannelMember *member = node->data;
 
     tlen = strlen(member->client->id) + 1;  /* +1 for space */
-
-    if (member->flags & CHFL_CHANOP)
-      ++tlen;
-    if (member->flags & CHFL_HALFOP)
-      ++tlen;
-    if (member->flags & CHFL_VOICE)
-      ++tlen;
+    tlen += member_get_prefix_len(member, true);
 
     /*
      * Space will be converted into CR, but we also need space for LF..
      * That's why we use '- 1' here -adx
      */
-    if (t + tlen - buf > IRCD_BUFSIZE - 1)
+    if (t + tlen - buf > sizeof(buf) - 1)
     {
       *(t - 1) = '\0';  /* Kill the space and terminate the string */
       sendto_one(client, "%s", buf);
       t = start;
     }
 
-    if (member->flags & CHFL_CHANOP)
-      *t++ = '@';
-    if (member->flags & CHFL_HALFOP)
-      *t++ = '%';
-    if (member->flags & CHFL_VOICE)
-      *t++ = '+';
-
-    strcpy(t, member->client->id);
-
-    t += strlen(t);
-    *t++ = ' ';
+    t += snprintf(t, sizeof(buf) - (t - buf), "%s%s ", member_get_prefix(member, true), member->client->id);
   }
 
   /* Should always be non-NULL unless we have a kind of persistent channels */
@@ -212,15 +255,15 @@ channel_send_mask_list(struct Client *client, const struct Channel *channel,
                        const dlink_list *list, const char flag)
 {
   dlink_node *node;
-  char mbuf[IRCD_BUFSIZE];
-  char pbuf[IRCD_BUFSIZE];
+  char modebuf[IRCD_BUFSIZE];
+  char parabuf[IRCD_BUFSIZE];
   size_t tlen, mlen, cur_len;
-  char *pp = pbuf;
+  char *pbuf = parabuf;
 
   if (dlink_list_length(list) == 0)
     return;
 
-  mlen = snprintf(mbuf, sizeof(mbuf), ":%s BMASK %ju %s %c :", me.id,
+  mlen = snprintf(modebuf, sizeof(modebuf), ":%s BMASK %ju %s %c :", me.id,
                   channel->creation_time, channel->name, flag);
   cur_len = mlen;
 
@@ -233,21 +276,21 @@ channel_send_mask_list(struct Client *client, const struct Channel *channel,
     /*
      * Send buffer and start over if we cannot fit another ban
      */
-    if (cur_len + (tlen - 1) > sizeof(pbuf) - 2)
+    if (cur_len + (tlen - 1) > sizeof(parabuf) - 2)
     {
-      *(pp - 1) = '\0';  /* Get rid of trailing space on buffer */
-      sendto_one(client, "%s%s", mbuf, pbuf);
+      *(pbuf - 1) = '\0';  /* Get rid of trailing space on buffer */
+      sendto_one(client, "%s%s", modebuf, parabuf);
 
       cur_len = mlen;
-      pp = pbuf;
+      pbuf = parabuf;
     }
 
-    pp += snprintf(pp, sizeof(pbuf) - (pp - pbuf), "%s ", ban->banstr);
+    pbuf += snprintf(pbuf, sizeof(parabuf) - (pbuf - parabuf), "%s ", ban->banstr);
     cur_len += tlen;
   }
 
-  *(pp - 1) = '\0';  /* Get rid of trailing space on buffer */
-  sendto_one(client, "%s%s", mbuf, pbuf);
+  *(pbuf - 1) = '\0';  /* Get rid of trailing space on buffer */
+  sendto_one(client, "%s%s", modebuf, parabuf);
 }
 
 /*! \brief Send "client" a full list of the modes for channel channel
@@ -260,7 +303,7 @@ channel_send_modes(struct Client *client, const struct Channel *channel)
   char modebuf[MODEBUFLEN] = "";
   char parabuf[MODEBUFLEN] = "";
 
-  channel_modes(channel, client, modebuf, parabuf);
+  channel_modes(channel, client, NULL, modebuf, parabuf);
   channel_send_members(client, channel, modebuf, parabuf);
 
   channel_send_mask_list(client, channel, &channel->banlist, 'b');
@@ -414,16 +457,15 @@ channel_pub_or_secret(const struct Channel *channel)
 /*! \brief lists all names on given channel
  * \param client   Pointer to client struct requesting names
  * \param channel  Pointer to channel block
- * \param show_eon Show RPL_ENDOFNAMES numeric or not
- *                 (don't want it with /names with no params)
  */
 void
-channel_member_names(struct Client *client, struct Channel *channel, bool show_eon)
+channel_send_namereply(struct Client *client, struct Channel *channel)
 {
   dlink_node *node;
   char buf[IRCD_BUFSIZE + 1];
-  int tlen = 0;
-  bool is_member = IsMember(client, channel);
+  char *bufptr = buf;
+  size_t masklen = 0;
+  bool is_member = member_find_link(client, channel) != NULL;
   bool multi_prefix = HasCap(client, CAP_MULTI_PREFIX) != 0;
   bool uhnames = HasCap(client, CAP_UHNAMES) != 0;
 
@@ -431,9 +473,9 @@ channel_member_names(struct Client *client, struct Channel *channel, bool show_e
 
   if (PubChannel(channel) || is_member == true)
   {
-    char *t = buf + snprintf(buf, sizeof(buf), numeric_form(RPL_NAMREPLY), me.name, client->name,
-                             channel_pub_or_secret(channel), channel->name);
-    char *start = t;
+    /* :me.name 353 client->name @ channel->name :+nick1 @nick2 %nick3 ...\r\n */
+    /* 1       23456            789             01                        2 3  */
+    size_t len = strlen(me.name) + strlen(client->name) + channel->name_len + 13;
 
     DLINK_FOREACH(node, channel->members.head)
     {
@@ -443,54 +485,44 @@ channel_member_names(struct Client *client, struct Channel *channel, bool show_e
         continue;
 
       if (uhnames == true)
-        tlen = strlen(member->client->name) + strlen(member->client->username) +
-               strlen(member->client->host) + 3;  /* +3 for ! + @ + space */
+        masklen = strlen(member->client->name) + strlen(member->client->username) +
+                  strlen(member->client->host) + 3;  /* +3 for ! + @ + space */
       else
-        tlen = strlen(member->client->name) + 1;  /* +1 for space */
+        masklen = strlen(member->client->name) + 1;  /* +1 for space */
 
-      if (multi_prefix == true)
-      {
-        if (member->flags & CHFL_CHANOP)
-          ++tlen;
-        if (member->flags & CHFL_HALFOP)
-          ++tlen;
-        if (member->flags & CHFL_VOICE)
-          ++tlen;
-      }
-      else
-      {
-        if (member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
-          ++tlen;
-      }
+      masklen += member_get_prefix_len(member, multi_prefix);
 
-      if (t + tlen - buf > IRCD_BUFSIZE - 2)
+      if ((bufptr - buf) + masklen + len > sizeof(buf))
       {
-        *(t - 1) = '\0';
-        sendto_one(client, "%s", buf);
-        t = start;
+        *(bufptr - 1) = '\0';
+        sendto_one_numeric(client, &me, RPL_NAMREPLY,
+                           channel_pub_or_secret(channel), channel->name, buf);
+        bufptr = buf;
       }
 
       if (uhnames == true)
-        t += sprintf(t, "%s%s!%s@%s ", get_member_status(member, multi_prefix),
-                     member->client->name, member->client->username,
-                     member->client->host);
+        bufptr += snprintf(bufptr, sizeof(buf) - (bufptr - buf), "%s%s!%s@%s ",
+                           member_get_prefix(member, multi_prefix),
+                           member->client->name, member->client->username,
+                           member->client->host);
       else
-        t += sprintf(t, "%s%s ", get_member_status(member, multi_prefix),
-                     member->client->name);
+        bufptr += snprintf(bufptr, sizeof(buf) - (bufptr - buf), "%s%s ",
+                           member_get_prefix(member, multi_prefix),
+                           member->client->name);
     }
 
-    if (tlen)
+    if (bufptr != buf)
     {
-      *(t - 1) = '\0';
-      sendto_one(client, "%s", buf);
+      *(bufptr - 1) = '\0';
+      sendto_one_numeric(client, &me, RPL_NAMREPLY,
+                         channel_pub_or_secret(channel), channel->name, buf);
     }
   }
 
-  if (show_eon == true)
-    sendto_one_numeric(client, &me, RPL_ENDOFNAMES, channel->name);
+  sendto_one_numeric(client, &me, RPL_ENDOFNAMES, channel->name);
 }
 
-/* get_member_status()
+/* member_get_prefix()
  *
  * inputs       - pointer to struct ChannelMember
  *              - YES if we can combine different flags
@@ -502,30 +534,59 @@ channel_member_names(struct Client *client, struct Channel *channel, bool show_e
  * (like in client_get_name)
  */
 const char *
-get_member_status(const struct ChannelMember *member, bool combine)
+member_get_prefix(const struct ChannelMember *member, bool combine)
 {
-  static char buffer[CMEMBER_STATUS_FLAGS_LEN + 1];  /* +1 for \0 */
-  char *p = buffer;
+  static char buf[CMEMBER_STATUS_FLAGS_LEN + 1];  /* +1 for \0 */
+  char *bufptr = buf;
 
   if (member->flags & CHFL_CHANOP)
   {
     if (combine == false)
       return "@";
-    *p++ = '@';
+    *bufptr++ = '@';
   }
 
   if (member->flags & CHFL_HALFOP)
   {
     if (combine == false)
       return "%";
-    *p++ = '%';
+    *bufptr++ = '%';
   }
 
   if (member->flags & CHFL_VOICE)
-    *p++ = '+';
-  *p = '\0';
+    *bufptr++ = '+';
+  *bufptr = '\0';
 
-  return buffer;
+  return buf;
+}
+
+size_t
+member_get_prefix_len(const struct ChannelMember *member, bool combine)
+{
+  size_t len = 0;
+
+  if (member->flags & CHFL_CHANOP)
+  {
+    if (combine == false)
+      return 1;
+    ++len;
+  }
+
+  if (member->flags & CHFL_HALFOP)
+  {
+    if (combine == false)
+      return 1;
+    ++len;
+  }
+
+  if (member->flags & CHFL_VOICE)
+  {
+    if (combine == false)
+      return 1;
+    ++len;
+  }
+
+  return len;
 }
 
 /*!
@@ -558,15 +619,10 @@ ban_matches(struct Client *client, struct Channel *channel, struct Ban *ban)
             match(ban->host, client->sockhost) == 0 || match(ban->host, client->host) == 0)
           return true;
         break;
-      case HM_IPV4:
-        if (client->ip.ss.ss_family == AF_INET)
-          if (match_ipv4(&client->ip, &ban->addr, ban->bits))
-            return true;
-        break;
       case HM_IPV6:
-        if (client->ip.ss.ss_family == AF_INET6)
-          if (match_ipv6(&client->ip, &ban->addr, ban->bits))
-            return true;
+      case HM_IPV4:
+        if (address_compare(&client->ip, &ban->addr, false, false, ban->bits) == true)
+          return true;
         break;
       default:
         assert(0);
@@ -661,14 +717,16 @@ can_join(struct Client *client, struct Channel *channel, const char *key)
   return extban_join_can_join(channel, client, NULL);
 }
 
-int
-has_member_flags(const struct ChannelMember *member, const unsigned int flags)
+bool
+member_has_flags(const struct ChannelMember *member, const unsigned int flags)
 {
-  return member && (member->flags & flags);
+  if (member && (member->flags & flags))
+    return true;
+  return false;
 }
 
 struct ChannelMember *
-find_channel_link(const struct Client *client, const struct Channel *channel)
+member_find_link(const struct Client *client, const struct Channel *channel)
 {
   dlink_node *node;
 
@@ -753,7 +811,7 @@ can_send(struct Channel *channel, struct Client *client,
     if (*message == '\001' && strncmp(message + 1, "ACTION ", 7))
       return ERR_NOCTCP;
 
-  if (member || (member = find_channel_link(client, channel)))
+  if (member || (member = member_find_link(client, channel)))
     if (member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
       return CAN_SEND_OPV;
 
@@ -812,18 +870,19 @@ check_spambot_warning(struct Client *client, const char *name)
 
     if (client->connection->oper_warn_count_down == 0)
     {
+      client->connection->oper_warn_count_down = OPER_SPAM_COUNTDOWN;
+
       /* It's already known as a possible spambot */
       if (name)
-        sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
+        sendto_realops_flags(UMODE_FLOOD, L_ALL, SEND_NOTICE,
                              "User %s (%s@%s) trying to join %s is a possible spambot",
                              client->name, client->username,
                              client->host, name);
       else
-        sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
+        sendto_realops_flags(UMODE_FLOOD, L_ALL, SEND_NOTICE,
                              "User %s (%s@%s) is a possible spambot",
                              client->name, client->username,
                              client->host);
-      client->connection->oper_warn_count_down = OPER_SPAM_COUNTDOWN;
     }
   }
   else
@@ -920,7 +979,7 @@ channel_do_join(struct Client *client, char *chan_list, char *key_list)
     struct Channel *channel = hash_find_channel(name);
     if (channel)
     {
-      if (IsMember(client, channel))
+      if (member_find_link(client, channel))
         continue;
 
       /* can_join() checks for +i, +l, key, bans, etc. */
@@ -1007,7 +1066,7 @@ channel_do_join(struct Client *client, char *chan_list, char *key_list)
                          channel->topic_info, channel->topic_time);
     }
 
-    channel_member_names(client, channel, true);
+    channel_send_namereply(client, channel);
 
     client->connection->last_join_time = event_base->time.sec_monotonic;
   }
@@ -1028,7 +1087,7 @@ channel_part_one_client(struct Client *client, const char *name, const char *rea
     return;
   }
 
-  struct ChannelMember *member = find_channel_link(client, channel);
+  struct ChannelMember *member = member_find_link(client, channel);
   if (member == NULL)
   {
     sendto_one_numeric(client, &me, ERR_NOTONCHANNEL, channel->name);
@@ -1068,7 +1127,7 @@ void
 channel_do_part(struct Client *client, char *channel, const char *reason)
 {
   char *p = NULL;
-  char buf[KICKLEN + 1] = "";
+  char buf[KICKLEN + 1] = "";  /* Essential that buf[0] = '\0' */
 
   assert(IsClient(client));
 
