@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 9357 2020-04-28 13:56:17Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -121,7 +121,7 @@ add_id(struct Client *client, struct Channel *channel, const char *banid, dlink_
                                                           ConfigChannel.max_bans))
     {
       sendto_one_numeric(client, &me, ERR_BANLISTFULL, channel->name, banid);
-      return false;
+      return NULL;
     }
 
     collapse(mask);
@@ -243,6 +243,7 @@ del_id(struct Client *client, struct Channel *channel, const char *banid, dlink_
 {
   static char mask[MODEBUFLEN];
   dlink_node *node;
+
   assert(banid);
 
   /* TBD: n!u@h formatting fo local clients */
@@ -275,7 +276,8 @@ del_id(struct Client *client, struct Channel *channel, const char *banid, dlink_
  * channel onto buffer mbuf with the parameters in pbuf.
  */
 void
-channel_modes(const struct Channel *channel, const struct Client *client, char *mbuf, char *pbuf)
+channel_modes(const struct Channel *channel, const struct Client *client,
+              const struct ChannelMember *member, char *mbuf, char *pbuf)
 {
   *mbuf++ = '+';
   *pbuf = '\0';
@@ -288,7 +290,7 @@ channel_modes(const struct Channel *channel, const struct Client *client, char *
   {
     *mbuf++ = 'l';
 
-    if (IsServer(client) || IsMember(client, channel))
+    if (IsServer(client) || member || (member = member_find_link(client, channel)))
       pbuf += sprintf(pbuf, "%u ", channel->mode.limit);
   }
 
@@ -296,7 +298,7 @@ channel_modes(const struct Channel *channel, const struct Client *client, char *
   {
     *mbuf++ = 'k';
 
-    if (IsServer(client) || IsMember(client, channel))
+    if (IsServer(client) || member || (member = member_find_link(client, channel)))
       sprintf(pbuf, "%s ", channel->mode.key);
   }
 
@@ -314,9 +316,10 @@ channel_modes(const struct Channel *channel, const struct Client *client, char *
 static char *
 fix_key(char *arg)
 {
-  unsigned char *s, *t, c;
+  unsigned char *s = (unsigned char *)arg;
+  unsigned char *t = (unsigned char *)arg;
 
-  for (s = t = (unsigned char *)arg; (c = *s) && s - (unsigned char *)arg < KEYLEN; ++s)
+  for (unsigned char c; (c = *s) && s - (unsigned char *)arg < KEYLEN; ++s)
   {
     c &= 0x7f;
 
@@ -377,7 +380,7 @@ static void
 chm_simple(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
            int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
-  if (mode->only_opers)
+  if (mode->only_opers == true)
   {
     if (MyClient(client) && !HasUMode(client, UMODE_OPER))
     {
@@ -389,7 +392,7 @@ chm_simple(struct Client *client, struct Channel *channel, int parc, int *parn,
     }
   }
 
-  if (mode->only_servers)
+  if (mode->only_servers == true)
   {
     if (!IsServer(client) && !HasFlag(client, FLAGS_SERVICE))
     {
@@ -566,7 +569,7 @@ chm_flag(struct Client *client, struct Channel *channel, int parc, int *parn, ch
   if (client_target == NULL)
     return;  /* find_chasing sends ERR_NOSUCHNICK */
 
-  struct ChannelMember *member = find_channel_link(client_target, channel);
+  struct ChannelMember *member = member_find_link(client_target, channel);
   if (member == NULL)
   {
     if (!(*errors & SM_ERR_NOTONCHANNEL))
@@ -581,14 +584,14 @@ chm_flag(struct Client *client, struct Channel *channel, int parc, int *parn, ch
 
   if (dir == MODE_ADD)  /* setting + */
   {
-    if (has_member_flags(member, mode->flag))
+    if (member_has_flags(member, mode->flag) == true)
       return;  /* No redundant mode changes */
 
     AddMemberFlag(member, mode->flag);
   }
   else if (dir == MODE_DEL)  /* setting - */
   {
-    if (has_member_flags(member, mode->flag) == 0)
+    if (member_has_flags(member, mode->flag) == false)
       return;  /* No redundant mode changes */
 
     DelMemberFlag(member, mode->flag);
@@ -734,10 +737,10 @@ get_channel_access(const struct Client *client,
   /* Just to be sure.. */
   assert(client == member->client);
 
-  if (has_member_flags(member, CHFL_CHANOP))
+  if (member_has_flags(member, CHFL_CHANOP) == true)
     return CHACCESS_CHANOP;
 
-  if (has_member_flags(member, CHFL_HALFOP))
+  if (member_has_flags(member, CHFL_HALFOP) == true)
     return CHACCESS_HALFOP;
 
   return CHACCESS_PEON;
@@ -753,8 +756,8 @@ get_channel_access(const struct Client *client,
 static void
 send_mode_changes_server(struct Client *client, struct Channel *channel)
 {
-  char modebuf[IRCD_BUFSIZE] = "";
-  char parabuf[IRCD_BUFSIZE] = "";
+  char modebuf[IRCD_BUFSIZE];
+  char parabuf[IRCD_BUFSIZE];
   char *parptr = parabuf;
   unsigned int mbl = 0, pbl = 0, arglen = 0, modecount = 0, paracount = 0;
   unsigned int dir = MODE_QUERY;
@@ -841,8 +844,8 @@ send_mode_changes_client(struct Client *client, struct Channel *channel)
 
   for (unsigned int pass = 2; pass--; flags = CHFL_CHANOP | CHFL_HALFOP)
   {
-    char modebuf[IRCD_BUFSIZE] = "";
-    char parabuf[IRCD_BUFSIZE] = "";
+    char modebuf[IRCD_BUFSIZE];
+    char parabuf[IRCD_BUFSIZE];
     char *parptr = parabuf;
     unsigned int mbl = 0, pbl = 0, arglen = 0, modecount = 0, paracount = 0;
     unsigned int dir = MODE_QUERY;
@@ -934,6 +937,7 @@ const struct chan_mode  cmode_tab[] =
   { .letter = 'v', .flag = CHFL_VOICE, .required_oplevel = CHACCESS_HALFOP, .func = chm_flag },
   { .letter = 'C', .mode = MODE_NOCTCP, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = 'I', .flag = CHFL_INVEX, .required_oplevel = CHACCESS_HALFOP, .func = chm_mask },
+  { .letter = 'K', .mode = MODE_NOKNOCK, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = 'L', .mode = MODE_EXTLIMIT, .required_oplevel = CHACCESS_HALFOP, .only_opers = true, .func = chm_simple },
   { .letter = 'M', .mode = MODE_MODREG, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = 'N', .mode = MODE_NONICKCHANGE, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
