@@ -21,7 +21,7 @@
 
 /*! \file client.c
  * \brief Controls clients.
- * \version $Id: client.c 9266 2020-02-12 16:55:29Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -46,7 +46,7 @@
 #include "memory.h"
 #include "hostmask.h"
 #include "listener.h"
-#include "watch.h"
+#include "monitor.h"
 #include "rng_mt.h"
 #include "parse.h"
 #include "ipcache.h"
@@ -146,7 +146,8 @@ client_free(struct Client *client)
 
 
   xfree(client->serv);
-  xfree(client->certfp);
+  xfree(client->tls_certfp);
+  xfree(client->tls_cipher);
 
   if (MyConnect(client))
   {
@@ -161,9 +162,9 @@ client_free(struct Client *client)
     assert(client->connection->acceptlist.tail == NULL);
 
 
-    assert(dlink_list_length(&client->connection->watches) == 0);
-    assert(client->connection->watches.head == NULL);
-    assert(client->connection->watches.tail == NULL);
+    assert(dlink_list_length(&client->connection->monitors) == 0);
+    assert(client->connection->monitors.head == NULL);
+    assert(client->connection->monitors.tail == NULL);
 
     assert(dlink_list_length(&client->connection->confs) == 0);
     assert(client->connection->confs.head == NULL);
@@ -676,7 +677,7 @@ exit_one_client(struct Client *client, const char *comment)
     whowas_add_history(client, false);
     whowas_off_history(client);
 
-    watch_check_hash(client, RPL_LOGOFF);
+    monitor_signoff(client);
   }
   else if (IsServer(client))
   {
@@ -772,11 +773,12 @@ exit_client(struct Client *client, const char *comment)
 
     if (IsClient(client))
     {
-      dlink_node *node;
-
       if (HasUMode(client, UMODE_OPER))
-        if ((node = dlinkFindDelete(&oper_list, client)))
+      {
+        dlink_node *node = dlinkFindDelete(&oper_list, client);
+        if (node)
           free_dlink_node(node);
+      }
 
       assert(dlinkFind(&local_client_list, client));
       dlinkDelete(&client->connection->lclient_node, &local_client_list);
@@ -786,7 +788,7 @@ exit_client(struct Client *client, const char *comment)
 
       invite_clear_list(&client->connection->invited);
       del_all_accepts(client);
-      watch_del_watch_list(client);
+      monitor_clear_list(client);
 
       sendto_realops_flags(UMODE_CCONN, L_ALL, SEND_NOTICE,
                            "Client exiting: %s (%s@%s) [%s] [%s]",
@@ -1055,7 +1057,7 @@ accept_message(struct Client *source,
 
   if (!HasUMode(target, UMODE_CALLERID) && HasUMode(target, UMODE_SOFTCALLERID))
     DLINK_FOREACH(node, target->channel.head)
-      if (IsMember(source, ((struct ChannelMember *)node->data)->channel))
+      if (member_find_link(source, ((struct ChannelMember *)node->data)->channel))
         return true;
 
   return false;
