@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 9332 2020-04-11 17:01:20Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -315,6 +315,9 @@ verify_access(struct Client *client)
     return NOT_AUTHORIZED;
   }
 
+  /* Preserve x->host in x->realhost before it gets overwritten. */
+  strlcpy(client->realhost, client->host, sizeof(client->realhost));
+
   if (IsConfDoSpoofIp(conf))
     strlcpy(client->host, conf->name, sizeof(client->host));
 
@@ -346,7 +349,7 @@ conf_check_client(struct Client *client)
   switch (i)
   {
     case TOO_MANY:
-      sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                            "Too many on IP for %s (%s).",
                            client_get_name(client, SHOW_IP),
                            client->sockhost);
@@ -357,7 +360,7 @@ conf_check_client(struct Client *client)
       break;
 
     case I_LINE_FULL:
-      sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                            "auth {} block is full for %s (%s).",
                            client_get_name(client, SHOW_IP),
                            client->sockhost);
@@ -368,18 +371,11 @@ conf_check_client(struct Client *client)
       break;
 
     case NOT_AUTHORIZED:
-      /* jdc - lists server name & port connections are on */
-      /*       a purely cosmetical change */
-      sendto_realops_flags(UMODE_UNAUTH, L_ALL, SEND_NOTICE,
-                           "Unauthorized client connection from %s on [%s/%u].",
-                           client_get_name(client, SHOW_IP),
-                           client->connection->listener->name,
-                           client->connection->listener->port);
-      ilog(LOG_TYPE_IRCD, "Unauthorized client connection from %s on [%s/%u].",
-           client_get_name(client, SHOW_IP),
-           client->connection->listener->name,
-           client->connection->listener->port);
-
+      sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
+                           "Unauthorized client connection from %s.",
+                           client_get_name(client, SHOW_IP));
+      ilog(LOG_TYPE_IRCD, "Unauthorized client connection from %s.",
+           client_get_name(client, SHOW_IP));
       ++ServerStats.is_ref;
       exit_client(client, "You are not authorized to use this server");
       break;
@@ -519,7 +515,7 @@ connect_find(const char *name, int (*compare)(const char *, const char *))
  * side effects - looks for an exact match on name field
  */
 struct MaskItem *
-operator_find(const struct Client *who, const char *name)
+operator_find(const struct Client *client, const char *name)
 {
   dlink_node *node;
 
@@ -529,29 +525,26 @@ operator_find(const struct Client *who, const char *name)
 
     if (irccmp(conf->name, name) == 0)
     {
-      if (who == NULL)
+      if (client == NULL)
         return conf;
 
-      if (match(conf->user, who->username) == 0)
+      if (conf->class->max_total &&
+          conf->class->max_total <= conf->class->ref_count)
+        continue;
+
+      if (match(conf->user, client->username) == 0)
       {
         switch (conf->htype)
         {
           case HM_HOST:
-            if (match(conf->host, who->host) == 0 || match(conf->host, who->sockhost) == 0)
-              if (conf->class->max_total == 0 || conf->class->ref_count < conf->class->max_total)
-                return conf;
-            break;
-          case HM_IPV4:
-            if (who->ip.ss.ss_family == AF_INET)
-              if (match_ipv4(&who->ip, conf->addr, conf->bits))
-                if (conf->class->max_total == 0 || conf->class->ref_count < conf->class->max_total)
-                  return conf;
+            if (match(conf->host, client->realhost) == 0 ||
+                match(conf->host, client->sockhost) == 0 || match(conf->host, client->host) == 0)
+              return conf;
             break;
           case HM_IPV6:
-            if (who->ip.ss.ss_family == AF_INET6)
-              if (match_ipv6(&who->ip, conf->addr, conf->bits))
-                if (conf->class->max_total == 0 || conf->class->ref_count < conf->class->max_total)
-                  return conf;
+          case HM_IPV4:
+            if (address_compare(&client->ip, conf->addr, false, false, conf->bits) == true)
+              return conf;
             break;
           default:
             assert(0);
@@ -582,7 +575,7 @@ conf_set_defaults(void)
   assert(class_default == class_get_list()->tail->data);
 
   ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
-  ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
+  ConfigServerInfo.network_description = xstrdup(NETWORK_DESCRIPTION_DEFAULT);
   ConfigServerInfo.default_max_clients = MAXCLIENTS_MAX;
   ConfigServerInfo.max_nick_length = 9;
   ConfigServerInfo.max_topic_length = 80;
@@ -619,7 +612,7 @@ conf_set_defaults(void)
 
   ConfigGeneral.away_count = 2;
   ConfigGeneral.away_time = 10;
-  ConfigGeneral.max_watch = 50;
+  ConfigGeneral.max_monitor = 50;
   ConfigGeneral.whowas_history_length = 15000;
   ConfigGeneral.cycle_on_host_change = 1;
   ConfigGeneral.dline_min_cidr = 16;
@@ -659,9 +652,9 @@ conf_set_defaults(void)
   ConfigGeneral.no_oper_flood = 0;
   ConfigGeneral.max_targets = MAX_TARGETS_DEFAULT;
   ConfigGeneral.oper_only_umodes = UMODE_DEBUG | UMODE_LOCOPS | UMODE_HIDDEN | UMODE_FARCONNECT |
-                                   UMODE_UNAUTH | UMODE_EXTERNAL | UMODE_BOTS | UMODE_NCHANGE |
-                                   UMODE_SPY | UMODE_FULL | UMODE_SKILL | UMODE_REJ | UMODE_CCONN;
-  ConfigGeneral.oper_umodes = UMODE_BOTS | UMODE_LOCOPS | UMODE_SERVNOTICE | UMODE_WALLOP;
+                                   UMODE_EXTERNAL | UMODE_FLOOD | UMODE_NCHANGE |
+                                   UMODE_SPY | UMODE_SKILL | UMODE_REJ | UMODE_CCONN;
+  ConfigGeneral.oper_umodes = UMODE_FLOOD | UMODE_LOCOPS | UMODE_SERVNOTICE | UMODE_WALLOP;
   ConfigGeneral.throttle_count = 1;
   ConfigGeneral.throttle_time = 1;
 }
@@ -672,8 +665,8 @@ conf_validate(void)
   if (EmptyString(ConfigServerInfo.network_name))
     ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
 
-  if (EmptyString(ConfigServerInfo.network_desc))
-    ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
+  if (EmptyString(ConfigServerInfo.network_description))
+    ConfigServerInfo.network_description = xstrdup(NETWORK_DESCRIPTION_DEFAULT);
 }
 
 /* conf_read()
@@ -786,7 +779,7 @@ cleanup_tklines(void *unused)
 const char *
 get_oper_name(const struct Client *client)
 {
-  static char buffer[IRCD_BUFSIZE];
+  static char buf[IRCD_BUFSIZE];
 
   if (IsServer(client))
     return client->name;
@@ -801,9 +794,9 @@ get_oper_name(const struct Client *client)
 
       if (conf->type == CONF_OPER)
       {
-        snprintf(buffer, sizeof(buffer), "%s!%s@%s{%s}", client->name,
+        snprintf(buf, sizeof(buf), "%s!%s@%s{%s}", client->name,
                  client->username, client->host, conf->name);
-        return buffer;
+        return buf;
       }
     }
 
@@ -814,9 +807,9 @@ get_oper_name(const struct Client *client)
     assert(0);  /* Oper without oper conf! */
   }
 
-  snprintf(buffer, sizeof(buffer), "%s!%s@%s{%s}", client->name,
+  snprintf(buf, sizeof(buf), "%s!%s@%s{%s}", client->name,
            client->username, client->host, client->servptr->name);
-  return buffer;
+  return buf;
 }
 
 /* conf_clear()
@@ -882,8 +875,8 @@ conf_clear(void)
   ConfigServerInfo.description = NULL;
   xfree(ConfigServerInfo.network_name);
   ConfigServerInfo.network_name = NULL;
-  xfree(ConfigServerInfo.network_desc);
-  ConfigServerInfo.network_desc = NULL;
+  xfree(ConfigServerInfo.network_description);
+  ConfigServerInfo.network_description = NULL;
   xfree(ConfigServerInfo.rsa_private_key_file);
   ConfigServerInfo.rsa_private_key_file = NULL;
   xfree(ConfigServerInfo.tls_certificate_file);
@@ -1001,7 +994,7 @@ conf_read_files(bool cold)
   isupport_add("CHANNELLEN", NULL, CHANNELLEN);
   isupport_add("TOPICLEN", NULL, ConfigServerInfo.max_topic_length);
 
-  snprintf(buf, sizeof(buf), "%s", "beI,k,l,cimnprstuCLMNORST");
+  snprintf(buf, sizeof(buf), "%s", "beI,k,l,cimnprstuCKLMNORST");
   isupport_add("CHANMODES", buf, -1);
 }
 
