@@ -21,7 +21,7 @@
 
 /*! \file conf_class.c
  * \brief Configuration managment for class{} blocks
- * \version $Id: conf_class.c 9249 2020-02-01 13:35:32Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -53,7 +53,6 @@ class_make(void)
   class->active = true;
   class->con_freq = DEFAULT_CONNECTFREQUENCY;
   class->ping_freq = DEFAULT_PINGFREQUENCY;
-  class->max_total = MAXIMUM_LINKS_DEFAULT;
   class->max_sendq = DEFAULT_SENDQ;
   class->max_recvq = DEFAULT_RECVQ;
   class->ip_tree_v6 = patricia_new(128);
@@ -145,7 +144,12 @@ class_find(const char *name, bool active)
     struct ClassItem *class = node->data;
 
     if (irccmp(class->name, name) == 0)
-      return active == true && class->active == false ? NULL : class;
+    {
+      if (active == true && class->active == false)
+        return NULL;
+
+      return class;
+    }
   }
 
   return NULL;
@@ -161,7 +165,10 @@ class_mark_for_deletion(void)
   dlink_node *node;
 
   DLINK_FOREACH_PREV(node, class_list.tail->prev)
-    ((struct ClassItem *)node->data)->active = false;
+  {
+    struct ClassItem *class = node->data;
+    class->active = false;
+  }
 }
 
 void
