@@ -21,7 +21,7 @@
 
 /*! \file hostmask.c
  * \brief Code to efficiently find IP & hostmask based configs.
- * \version $Id: hostmask.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -272,6 +272,43 @@ parse_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   return HM_HOST;
 }
 
+bool
+address_compare(const void *p1, const void *p2, bool exact, bool port, int bits)
+{
+  const struct irc_ssaddr *const addr = p1;
+  const struct irc_ssaddr *const mask = p2;
+
+  if (addr->ss.ss_family != mask->ss.ss_family)
+    return false;
+
+  if (addr->ss.ss_family == AF_INET)
+  {
+    const struct sockaddr_in *const sin1 = (const struct sockaddr_in *)addr;
+    const struct sockaddr_in *const sin2 = (const struct sockaddr_in *)mask;
+
+    if (port == true && (sin1->sin_port != sin2->sin_port))
+      return false; 
+    if (exact == true)
+      return sin1->sin_addr.s_addr == sin2->sin_addr.s_addr;
+    return match_ipv4(addr, mask, bits);
+  }
+  else if (addr->ss.ss_family == AF_INET6)
+  {
+    const struct sockaddr_in6 *const sin1 = (const struct sockaddr_in6 *)addr;
+    const struct sockaddr_in6 *const sin2 = (const struct sockaddr_in6 *)mask;
+
+    if (port == true && (sin1->sin6_port != sin2->sin6_port))
+      return false;
+
+    if (exact == true)
+      return memcmp(sin1->sin6_addr.s6_addr,
+                    sin2->sin6_addr.s6_addr, sizeof(struct in6_addr)) == 0;
+    return match_ipv6(addr, mask, bits);
+  }
+
+  return false;
+}
+
 /* The address matching stuff... */
 /* int match_ipv6(struct irc_ssaddr *, struct irc_ssaddr *, int)
  * Input: An IP address, an IP mask, the number of bits in the mask.
