@@ -21,7 +21,7 @@
 
 /*! \file listener.c
  * \brief Implementation for handling listening sockets.
- * \version $Id: listener.c 9156 2020-01-13 14:51:47Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -81,6 +81,14 @@ listener_get_name(const struct Listener *listener)
   return buf;
 }
 
+bool
+listener_has_flag(const struct Listener *listener, unsigned int flags)
+{
+  if (listener && (listener->flags & flags))
+    return true;
+  return false;
+}
+
 void
 listener_count_memory(unsigned int *count, size_t *bytes)
 {
@@ -178,7 +186,7 @@ listener_accept_connection(fde_t *F, void *data)
 #define HYBRID_SOMAXCONN SOMAXCONN
 #endif
 
-static int
+static bool
 inetport(struct Listener *listener)
 {
   socklen_t opt = 1;
@@ -194,7 +202,7 @@ inetport(struct Listener *listener)
   {
     report_error(L_ALL, "opening listener socket %s:%s",
                  listener_get_name(listener), errno);
-    return 0;
+    return false;
   }
 
   if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(opt)))
@@ -202,7 +210,7 @@ inetport(struct Listener *listener)
     report_error(L_ALL, "setting SO_REUSEADDR for listener %s:%s",
                  listener_get_name(listener), errno);
     close(fd);
-    return 0;
+    return false;
   }
 
   /*
@@ -214,7 +222,7 @@ inetport(struct Listener *listener)
     report_error(L_ALL, "binding listener socket %s:%s",
                  listener_get_name(listener), errno);
     close(fd);
-    return 0;
+    return false;
   }
 
   if (listen(fd, HYBRID_SOMAXCONN))
@@ -222,15 +230,34 @@ inetport(struct Listener *listener)
     report_error(L_ALL, "listen failed for %s:%s",
                  listener_get_name(listener), errno);
     close(fd);
-    return 0;
+    return false;
   }
 
+#ifdef TCP_DEFER_ACCEPT
+  if (listener_has_flag(listener, LISTENER_DEFER))
+  {
+    int timeout = 1;
+
+    setsockopt(fd, IPPROTO_TCP, TCP_DEFER_ACCEPT, &timeout, sizeof(timeout));
+  }
+#endif
+#ifdef SO_ACCEPTFILTER
+  if (listener_has_flag(listener, LISTENER_DEFER))
+  {
+    struct accept_filter_arg afa;
+
+    memset(&afa, 0, sizeof(afa));
+    strlcpy(afa.af_name, "dataready", sizeof(afa.af_name));
+    setsockopt(fd, SOL_SOCKET, SO_ACCEPTFILTER, &afa, sizeof(afa));
+  }
+#endif
+
   listener->fd = fd_open(fd, true, "Listener socket");
 
   /* Listen completion events are READ events .. */
 
   listener_accept_connection(listener->fd, listener);
-  return 1;
+  return true;
 }
 
 static struct Listener *
@@ -275,7 +302,7 @@ listener_close(struct Listener *listener)
     listener->fd = NULL;
   }
 
-  listener->active = 0;
+  listener->active = false;
 
   if (listener->ref_count)
     return;
@@ -301,7 +328,7 @@ listener_release(struct Listener *listener)
 {
   assert(listener->ref_count > 0);
 
-  if (--listener->ref_count == 0 && !listener->active)
+  if (--listener->ref_count == 0 && listener->active == false)
     listener_close(listener);
 }
 
@@ -396,8 +423,8 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
     listener->flags = flags;
   }
 
-  if (inetport(listener))
-    listener->active = 1;
+  if (inetport(listener) == true)
+    listener->active = true;
   else
     listener_close(listener);
 }
