@@ -21,7 +21,7 @@
 
 /*! \file parse.c
  * \brief The message parser.
- * \version $Id: parse.c 9249 2020-02-01 13:35:32Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -156,30 +156,12 @@ parse_remove_unknown(struct Client *client, const char *lsender, char *lbuffer)
 static void
 parse_handle_numeric(unsigned int numeric, struct Client *source, int parc, char *parv[])
 {
-  struct Client *target = NULL;
-  struct Channel *channel = NULL;
-
   /*
    * Avoid trash, we need it to come from a server and have a target
    */
   if (parc < 2 || !IsServer(source))
     return;
 
-  /*
-   * Who should receive this message ? Will we do something with it ?
-   * Note that we use findUser functions, so the target can't be neither
-   * a server, nor a channel (?) nor a list of targets (?) .. u2.10
-   * should never generate numeric replies to non-users anyway
-   * Ahem... it can be a channel actually, csc bots use it :\ --Nem
-   */
-  if (IsChanPrefix(*parv[1]))
-    channel = hash_find_channel(parv[1]);
-  else
-    target = find_person(source, parv[1]);
-
-  if ((target == NULL || target->from == source->from) && channel == NULL)
-    return;
-
   /*
    * Remap low number numerics, not that I understand WHY.. --Nemesi
    */
@@ -192,8 +174,28 @@ parse_handle_numeric(unsigned int numeric, struct Client *source, int parc, char
   if (numeric < 100)
     numeric += 100;
 
-  if (target)
+  /*
+   * Who should receive this message ? Will we do something with it ?
+   * Note that we use findUser functions, so the target can't be neither
+   * a server, nor a channel (?) nor a list of targets (?) .. u2.10
+   * should never generate numeric replies to non-users anyway
+   * Ahem... it can be a channel actually, csc bots use it :\ --Nem
+   */
+  if (IsChanPrefix(*parv[1]))
   {
+    struct Channel *channel = hash_find_channel(parv[1]);
+    if (channel == NULL)
+      return;
+
+    sendto_channel_butone(source, source, channel, 0, "%u %s %s",
+                          numeric, channel->name, parv[2]);
+  }
+  else
+  {
+    struct Client *target = find_person(source, parv[1]);
+    if (target == NULL || target->from == source->from)
+      return;
+
     /* Fake it for server hiding, if it's our client */
     if ((ConfigServerHide.hide_servers || IsHidden(source)) && MyConnect(target) &&
         !HasUMode(target, UMODE_OPER))
@@ -201,9 +203,6 @@ parse_handle_numeric(unsigned int numeric, struct Client *source, int parc, char
     else
       sendto_one_numeric(target, source, numeric | SND_EXPLICIT, "%s", parv[2]);
   }
-  else
-    sendto_channel_butone(source, source, channel, 0, "%u %s %s",
-                          numeric, channel->name, parv[2]);
 }
 
 /* handle_command()
@@ -220,18 +219,22 @@ static void
 parse_handle_command(struct Message *message, struct Client *source,
                      unsigned int i, char *para[])
 {
+  const struct MessageHandler *const handler = &message->handlers[source->from->handler];
+
   if (IsServer(source->from))
     ++message->rcount;
   ++message->count;
 
-  if (MyClient(source) && (message->flags & MFLG_ENDGRACE))
+  if (handler->end_grace_period == true && MyClient(source))
     flood_endgrace(source);
 
   /* Check right amount of parameters is passed... --is */
-  if (i < message->args_min)
+  if (handler->args_min &&
+      ((i < handler->args_min) ||
+       (handler->empty_last_arg != true && EmptyString(para[handler->args_min - 1]))))
     sendto_one_numeric(source, &me, ERR_NEEDMOREPARAMS, message->cmd);
   else
-    message->handlers[source->from->handler](source, i, para);
+    handler->handler(source, i, para);
 }
 
 /*
@@ -251,14 +254,10 @@ parse(struct Client *client, char *pbuffer, char *bufend)
   unsigned int parc = 0;
   unsigned int paramcount;
 
-  if (IsDead(client))
-    return;
-
+  assert(!IsDead(client));
   assert(client->connection);
   assert(client->connection->fd);
   assert(client->connection->fd->flags.open);
-
-
   assert((bufend - pbuffer) < IRCD_BUFSIZE);
 
   for (ch = pbuffer; *ch == ' '; ++ch)  /* Skip spaces */
@@ -366,12 +365,23 @@ parse(struct Client *client, char *pbuffer, char *bufend)
 
     assert(message->cmd);
 
-    paramcount = message->args_max;
+    paramcount = message->handlers[from->from->handler].args_max;
 
     size_t length = bufend - ((s) ? s : ch);
     message->bytes += length;
   }
 
+  memset(para, 0, sizeof(para));
+  para[parc] = ch;
+
+  if (message && message->extra)
+  {
+    /*
+     * XXX: This will have to go away after the command handler rewrite
+     */
+    para[++parc] = message->extra;
+  }
+
   /*
    * Must the following loop really be so devious? On surface it
    * splits the message to parameters from blank spaces. But, if
@@ -380,20 +390,9 @@ parse(struct Client *client, char *pbuffer, char *bufend)
    */
 
   /* Note initially true: s == NULL || *(s - 1) == '\0' !! */
-
-  para[parc] = ch;
-
-  if (message && (message->flags & MFLG_EXTRA))
-  {
-    /*
-     * XXX: This will have to go away after the command handler rewrite
-     */
-    para[++parc] = message->extra;
-  }
-
   if (s)
   {
-    if (paramcount > MAXPARA)
+    if (paramcount == 0 || paramcount > MAXPARA)
       paramcount = MAXPARA;
 
     while (true)
@@ -604,8 +603,10 @@ recurse_report_messages(struct Client *source, const struct MessageTree *mtree)
   if (mtree->msg)
     sendto_one_numeric(source, &me, RPL_STATSCOMMANDS,
                        mtree->msg->cmd,
-                       mtree->msg->count, mtree->msg->bytes,
-                       mtree->msg->rcount);
+                       mtree->msg->count,
+                       mtree->msg->bytes,
+                       mtree->msg->rcount,
+                       mtree->msg->ecount);
 
   for (unsigned int i = 0; i < MAXPTRLEN; ++i)
     if (mtree->pointers[i])
