@@ -21,7 +21,7 @@
 
 /*! \file server_capab.c
  * \brief Server CAPAB related functions.
- * \version $Id: server_capab.c 9102 2020-01-01 09:58:57Z michael $
+ * \version $Id$
  */
 
 #include "stdinc.h"
@@ -44,10 +44,8 @@ static dlink_list capab_list;  /* List of capabilities supported by this server
 void
 capab_init(void)
 {
-  capab_add("QS", CAPAB_QS);
   capab_add("EOB", CAPAB_EOB);
   capab_add("CLUSTER", CAPAB_CLUSTER);
-  capab_add("SVS", CAPAB_SVS);
   capab_add("RHOST", CAPAB_RHOST);
 }
 
